From 4c4407a8930267e139db93019c01444acf49e1ce Mon Sep 17 00:00:00 2001
From: Branislav Kontur <bkontur@gmail.com>
Date: Wed, 13 Dec 2023 12:33:19 +0100
Subject: [PATCH] Updated benchmarks related to the Rococo/Westend bridge
 (#2639)

Co-authored-by: command-bot <>
---
 .../weights/pallet_xcm_bridge_hub_router.rs   |  20 +-
 .../weights/pallet_xcm_bridge_hub_router.rs   |  20 +-
 .../src/weights/pallet_bridge_grandpa.rs      |  16 +-
 .../src/weights/pallet_bridge_messages.rs     |  58 +++---
 .../src/weights/pallet_bridge_parachains.rs   |  20 +-
 .../src/weights/pallet_bridge_relayers.rs     |  34 ++--
 .../xcm/pallet_xcm_benchmarks_generic.rs      | 130 ++++++------
 .../src/weights/pallet_bridge_grandpa.rs      |  28 ++-
 .../src/weights/pallet_bridge_messages.rs     | 187 +++++++++---------
 .../src/weights/pallet_bridge_parachains.rs   |  78 ++++----
 .../src/weights/pallet_bridge_relayers.rs     |  30 +--
 .../xcm/pallet_xcm_benchmarks_generic.rs      | 142 +++++++------
 12 files changed, 376 insertions(+), 387 deletions(-)

diff --git a/cumulus/parachains/runtimes/assets/asset-hub-rococo/src/weights/pallet_xcm_bridge_hub_router.rs b/cumulus/parachains/runtimes/assets/asset-hub-rococo/src/weights/pallet_xcm_bridge_hub_router.rs
index aeaaed45452..775bc3bdb80 100644
--- a/cumulus/parachains/runtimes/assets/asset-hub-rococo/src/weights/pallet_xcm_bridge_hub_router.rs
+++ b/cumulus/parachains/runtimes/assets/asset-hub-rococo/src/weights/pallet_xcm_bridge_hub_router.rs
@@ -17,9 +17,9 @@
 //! Autogenerated weights for `pallet_xcm_bridge_hub_router`
 //!
 //! THIS FILE WAS AUTO-GENERATED USING THE SUBSTRATE BENCHMARK CLI VERSION 4.0.0-dev
-//! DATE: 2023-11-29, STEPS: `50`, REPEAT: `20`, LOW RANGE: `[]`, HIGH RANGE: `[]`
+//! DATE: 2023-12-12, STEPS: `50`, REPEAT: `20`, LOW RANGE: `[]`, HIGH RANGE: `[]`
 //! WORST CASE MAP SIZE: `1000000`
-//! HOSTNAME: `runner-r43aesjn-project-674-concurrent-0`, CPU: `Intel(R) Xeon(R) CPU @ 2.60GHz`
+//! HOSTNAME: `runner-itmxxexx-project-674-concurrent-0`, CPU: `Intel(R) Xeon(R) CPU @ 2.60GHz`
 //! WASM-EXECUTION: `Compiled`, CHAIN: `Some("asset-hub-rococo-dev")`, DB CACHE: 1024
 
 // Executed Command:
@@ -58,8 +58,8 @@ impl<T: frame_system::Config> pallet_xcm_bridge_hub_router::WeightInfo for Weigh
 		// Proof Size summary in bytes:
 		//  Measured:  `154`
 		//  Estimated: `1639`
-		// Minimum execution time: 8_110_000 picoseconds.
-		Weight::from_parts(8_373_000, 0)
+		// Minimum execution time: 7_853_000 picoseconds.
+		Weight::from_parts(8_443_000, 0)
 			.saturating_add(Weight::from_parts(0, 1639))
 			.saturating_add(T::DbWeight::get().reads(3))
 			.saturating_add(T::DbWeight::get().writes(1))
@@ -72,8 +72,8 @@ impl<T: frame_system::Config> pallet_xcm_bridge_hub_router::WeightInfo for Weigh
 		// Proof Size summary in bytes:
 		//  Measured:  `144`
 		//  Estimated: `1629`
-		// Minimum execution time: 4_459_000 picoseconds.
-		Weight::from_parts(4_663_000, 0)
+		// Minimum execution time: 4_333_000 picoseconds.
+		Weight::from_parts(4_501_000, 0)
 			.saturating_add(Weight::from_parts(0, 1629))
 			.saturating_add(T::DbWeight::get().reads(2))
 	}
@@ -83,8 +83,8 @@ impl<T: frame_system::Config> pallet_xcm_bridge_hub_router::WeightInfo for Weigh
 		// Proof Size summary in bytes:
 		//  Measured:  `150`
 		//  Estimated: `1502`
-		// Minimum execution time: 10_153_000 picoseconds.
-		Weight::from_parts(10_737_000, 0)
+		// Minimum execution time: 10_167_000 picoseconds.
+		Weight::from_parts(10_667_000, 0)
 			.saturating_add(Weight::from_parts(0, 1502))
 			.saturating_add(T::DbWeight::get().reads(1))
 			.saturating_add(T::DbWeight::get().writes(1))
@@ -117,8 +117,8 @@ impl<T: frame_system::Config> pallet_xcm_bridge_hub_router::WeightInfo for Weigh
 		// Proof Size summary in bytes:
 		//  Measured:  `448`
 		//  Estimated: `6388`
-		// Minimum execution time: 61_258_000 picoseconds.
-		Weight::from_parts(63_679_000, 0)
+		// Minimum execution time: 60_584_000 picoseconds.
+		Weight::from_parts(62_467_000, 0)
 			.saturating_add(Weight::from_parts(0, 6388))
 			.saturating_add(T::DbWeight::get().reads(12))
 			.saturating_add(T::DbWeight::get().writes(4))
diff --git a/cumulus/parachains/runtimes/assets/asset-hub-westend/src/weights/pallet_xcm_bridge_hub_router.rs b/cumulus/parachains/runtimes/assets/asset-hub-westend/src/weights/pallet_xcm_bridge_hub_router.rs
index ee8d0ae3c45..84d717b0283 100644
--- a/cumulus/parachains/runtimes/assets/asset-hub-westend/src/weights/pallet_xcm_bridge_hub_router.rs
+++ b/cumulus/parachains/runtimes/assets/asset-hub-westend/src/weights/pallet_xcm_bridge_hub_router.rs
@@ -17,9 +17,9 @@
 //! Autogenerated weights for `pallet_xcm_bridge_hub_router`
 //!
 //! THIS FILE WAS AUTO-GENERATED USING THE SUBSTRATE BENCHMARK CLI VERSION 4.0.0-dev
-//! DATE: 2023-11-29, STEPS: `50`, REPEAT: `20`, LOW RANGE: `[]`, HIGH RANGE: `[]`
+//! DATE: 2023-12-12, STEPS: `50`, REPEAT: `20`, LOW RANGE: `[]`, HIGH RANGE: `[]`
 //! WORST CASE MAP SIZE: `1000000`
-//! HOSTNAME: `runner-r43aesjn-project-674-concurrent-0`, CPU: `Intel(R) Xeon(R) CPU @ 2.60GHz`
+//! HOSTNAME: `runner-itmxxexx-project-674-concurrent-0`, CPU: `Intel(R) Xeon(R) CPU @ 2.60GHz`
 //! WASM-EXECUTION: `Compiled`, CHAIN: `Some("asset-hub-westend-dev")`, DB CACHE: 1024
 
 // Executed Command:
@@ -58,8 +58,8 @@ impl<T: frame_system::Config> pallet_xcm_bridge_hub_router::WeightInfo for Weigh
 		// Proof Size summary in bytes:
 		//  Measured:  `193`
 		//  Estimated: `1678`
-		// Minimum execution time: 8_460_000 picoseconds.
-		Weight::from_parts(8_730_000, 0)
+		// Minimum execution time: 8_095_000 picoseconds.
+		Weight::from_parts(8_393_000, 0)
 			.saturating_add(Weight::from_parts(0, 1678))
 			.saturating_add(T::DbWeight::get().reads(3))
 			.saturating_add(T::DbWeight::get().writes(1))
@@ -72,8 +72,8 @@ impl<T: frame_system::Config> pallet_xcm_bridge_hub_router::WeightInfo for Weigh
 		// Proof Size summary in bytes:
 		//  Measured:  `111`
 		//  Estimated: `1596`
-		// Minimum execution time: 3_469_000 picoseconds.
-		Weight::from_parts(3_696_000, 0)
+		// Minimum execution time: 3_417_000 picoseconds.
+		Weight::from_parts(3_583_000, 0)
 			.saturating_add(Weight::from_parts(0, 1596))
 			.saturating_add(T::DbWeight::get().reads(2))
 	}
@@ -83,8 +83,8 @@ impl<T: frame_system::Config> pallet_xcm_bridge_hub_router::WeightInfo for Weigh
 		// Proof Size summary in bytes:
 		//  Measured:  `117`
 		//  Estimated: `1502`
-		// Minimum execution time: 10_315_000 picoseconds.
-		Weight::from_parts(10_651_000, 0)
+		// Minimum execution time: 10_280_000 picoseconds.
+		Weight::from_parts(10_703_000, 0)
 			.saturating_add(Weight::from_parts(0, 1502))
 			.saturating_add(T::DbWeight::get().reads(1))
 			.saturating_add(T::DbWeight::get().writes(1))
@@ -117,8 +117,8 @@ impl<T: frame_system::Config> pallet_xcm_bridge_hub_router::WeightInfo for Weigh
 		// Proof Size summary in bytes:
 		//  Measured:  `487`
 		//  Estimated: `6427`
-		// Minimum execution time: 64_532_000 picoseconds.
-		Weight::from_parts(66_901_000, 0)
+		// Minimum execution time: 63_624_000 picoseconds.
+		Weight::from_parts(66_071_000, 0)
 			.saturating_add(Weight::from_parts(0, 6427))
 			.saturating_add(T::DbWeight::get().reads(12))
 			.saturating_add(T::DbWeight::get().writes(4))
diff --git a/cumulus/parachains/runtimes/bridge-hubs/bridge-hub-rococo/src/weights/pallet_bridge_grandpa.rs b/cumulus/parachains/runtimes/bridge-hubs/bridge-hub-rococo/src/weights/pallet_bridge_grandpa.rs
index aaa6a3e0622..8c2435599f5 100644
--- a/cumulus/parachains/runtimes/bridge-hubs/bridge-hub-rococo/src/weights/pallet_bridge_grandpa.rs
+++ b/cumulus/parachains/runtimes/bridge-hubs/bridge-hub-rococo/src/weights/pallet_bridge_grandpa.rs
@@ -17,9 +17,9 @@
 //! Autogenerated weights for `pallet_bridge_grandpa`
 //!
 //! THIS FILE WAS AUTO-GENERATED USING THE SUBSTRATE BENCHMARK CLI VERSION 4.0.0-dev
-//! DATE: 2023-11-14, STEPS: `50`, REPEAT: `20`, LOW RANGE: `[]`, HIGH RANGE: `[]`
+//! DATE: 2023-12-12, STEPS: `50`, REPEAT: `20`, LOW RANGE: `[]`, HIGH RANGE: `[]`
 //! WORST CASE MAP SIZE: `1000000`
-//! HOSTNAME: `runner-yprdrvc7-project-674-concurrent-0`, CPU: `Intel(R) Xeon(R) CPU @ 2.60GHz`
+//! HOSTNAME: `runner-itmxxexx-project-674-concurrent-0`, CPU: `Intel(R) Xeon(R) CPU @ 2.60GHz`
 //! WASM-EXECUTION: `Compiled`, CHAIN: `Some("bridge-hub-rococo-dev")`, DB CACHE: 1024
 
 // Executed Command:
@@ -66,13 +66,13 @@ impl<T: frame_system::Config> pallet_bridge_grandpa::WeightInfo for WeightInfo<T
 		// Proof Size summary in bytes:
 		//  Measured:  `335 + p * (60 ±0)`
 		//  Estimated: `51735`
-		// Minimum execution time: 311_267_000 picoseconds.
-		Weight::from_parts(313_903_000, 0)
+		// Minimum execution time: 310_124_000 picoseconds.
+		Weight::from_parts(18_294_977, 0)
 			.saturating_add(Weight::from_parts(0, 51735))
-			// Standard Error: 4_779
-			.saturating_add(Weight::from_parts(55_265_953, 0).saturating_mul(p.into()))
-			// Standard Error: 36_883
-			.saturating_add(Weight::from_parts(153_660, 0).saturating_mul(v.into()))
+			// Standard Error: 5_665
+			.saturating_add(Weight::from_parts(55_380_719, 0).saturating_mul(p.into()))
+			// Standard Error: 94_494
+			.saturating_add(Weight::from_parts(2_765_959, 0).saturating_mul(v.into()))
 			.saturating_add(T::DbWeight::get().reads(5))
 			.saturating_add(T::DbWeight::get().writes(5))
 	}
diff --git a/cumulus/parachains/runtimes/bridge-hubs/bridge-hub-rococo/src/weights/pallet_bridge_relayers.rs b/cumulus/parachains/runtimes/bridge-hubs/bridge-hub-rococo/src/weights/pallet_bridge_relayers.rs
index 70af694645d..5ab4cb900d8 100644
--- a/cumulus/parachains/runtimes/bridge-hubs/bridge-hub-rococo/src/weights/pallet_bridge_relayers.rs
+++ b/cumulus/parachains/runtimes/bridge-hubs/bridge-hub-rococo/src/weights/pallet_bridge_relayers.rs
@@ -17,9 +17,9 @@
 //! Autogenerated weights for `pallet_bridge_relayers`
 //!
 //! THIS FILE WAS AUTO-GENERATED USING THE SUBSTRATE BENCHMARK CLI VERSION 4.0.0-dev
-//! DATE: 2023-11-14, STEPS: `50`, REPEAT: `20`, LOW RANGE: `[]`, HIGH RANGE: `[]`
+//! DATE: 2023-12-12, STEPS: `50`, REPEAT: `20`, LOW RANGE: `[]`, HIGH RANGE: `[]`
 //! WORST CASE MAP SIZE: `1000000`
-//! HOSTNAME: `runner-yprdrvc7-project-674-concurrent-0`, CPU: `Intel(R) Xeon(R) CPU @ 2.60GHz`
+//! HOSTNAME: `runner-itmxxexx-project-674-concurrent-0`, CPU: `Intel(R) Xeon(R) CPU @ 2.60GHz`
 //! WASM-EXECUTION: `Compiled`, CHAIN: `Some("bridge-hub-rococo-dev")`, DB CACHE: 1024
 
 // Executed Command:
@@ -54,10 +54,10 @@ impl<T: frame_system::Config> pallet_bridge_relayers::WeightInfo for WeightInfo<
 	/// Proof: `System::Account` (`max_values`: None, `max_size`: Some(128), added: 2603, mode: `MaxEncodedLen`)
 	fn claim_rewards() -> Weight {
 		// Proof Size summary in bytes:
-		//  Measured:  `207`
+		//  Measured:  `244`
 		//  Estimated: `3593`
-		// Minimum execution time: 46_579_000 picoseconds.
-		Weight::from_parts(48_298_000, 0)
+		// Minimum execution time: 45_393_000 picoseconds.
+		Weight::from_parts(46_210_000, 0)
 			.saturating_add(Weight::from_parts(0, 3593))
 			.saturating_add(T::DbWeight::get().reads(2))
 			.saturating_add(T::DbWeight::get().writes(2))
@@ -70,10 +70,10 @@ impl<T: frame_system::Config> pallet_bridge_relayers::WeightInfo for WeightInfo<
 	/// Proof: `Balances::Reserves` (`max_values`: None, `max_size`: Some(1249), added: 3724, mode: `MaxEncodedLen`)
 	fn register() -> Weight {
 		// Proof Size summary in bytes:
-		//  Measured:  `61`
+		//  Measured:  `97`
 		//  Estimated: `4714`
-		// Minimum execution time: 24_219_000 picoseconds.
-		Weight::from_parts(24_993_000, 0)
+		// Minimum execution time: 23_767_000 picoseconds.
+		Weight::from_parts(24_217_000, 0)
 			.saturating_add(Weight::from_parts(0, 4714))
 			.saturating_add(T::DbWeight::get().reads(3))
 			.saturating_add(T::DbWeight::get().writes(2))
@@ -84,10 +84,10 @@ impl<T: frame_system::Config> pallet_bridge_relayers::WeightInfo for WeightInfo<
 	/// Proof: `Balances::Reserves` (`max_values`: None, `max_size`: Some(1249), added: 3724, mode: `MaxEncodedLen`)
 	fn deregister() -> Weight {
 		// Proof Size summary in bytes:
-		//  Measured:  `160`
+		//  Measured:  `197`
 		//  Estimated: `4714`
-		// Minimum execution time: 26_279_000 picoseconds.
-		Weight::from_parts(26_810_000, 0)
+		// Minimum execution time: 25_745_000 picoseconds.
+		Weight::from_parts(26_319_000, 0)
 			.saturating_add(Weight::from_parts(0, 4714))
 			.saturating_add(T::DbWeight::get().reads(2))
 			.saturating_add(T::DbWeight::get().writes(2))
@@ -100,10 +100,10 @@ impl<T: frame_system::Config> pallet_bridge_relayers::WeightInfo for WeightInfo<
 	/// Proof: `System::Account` (`max_values`: None, `max_size`: Some(128), added: 2603, mode: `MaxEncodedLen`)
 	fn slash_and_deregister() -> Weight {
 		// Proof Size summary in bytes:
-		//  Measured:  `263`
+		//  Measured:  `300`
 		//  Estimated: `4714`
-		// Minimum execution time: 27_672_000 picoseconds.
-		Weight::from_parts(28_946_000, 0)
+		// Minimum execution time: 27_497_000 picoseconds.
+		Weight::from_parts(27_939_000, 0)
 			.saturating_add(Weight::from_parts(0, 4714))
 			.saturating_add(T::DbWeight::get().reads(3))
 			.saturating_add(T::DbWeight::get().writes(3))
@@ -112,10 +112,10 @@ impl<T: frame_system::Config> pallet_bridge_relayers::WeightInfo for WeightInfo<
 	/// Proof: `BridgeRelayers::RelayerRewards` (`max_values`: None, `max_size`: Some(73), added: 2548, mode: `MaxEncodedLen`)
 	fn register_relayer_reward() -> Weight {
 		// Proof Size summary in bytes:
-		//  Measured:  `6`
+		//  Measured:  `42`
 		//  Estimated: `3538`
-		// Minimum execution time: 5_487_000 picoseconds.
-		Weight::from_parts(5_725_000, 0)
+		// Minimum execution time: 5_584_000 picoseconds.
+		Weight::from_parts(5_908_000, 0)
 			.saturating_add(Weight::from_parts(0, 3538))
 			.saturating_add(T::DbWeight::get().reads(1))
 			.saturating_add(T::DbWeight::get().writes(1))
diff --git a/cumulus/parachains/runtimes/bridge-hubs/bridge-hub-rococo/src/weights/xcm/pallet_xcm_benchmarks_generic.rs b/cumulus/parachains/runtimes/bridge-hubs/bridge-hub-rococo/src/weights/xcm/pallet_xcm_benchmarks_generic.rs
index 606e47457d2..abd84f8e89b 100644
--- a/cumulus/parachains/runtimes/bridge-hubs/bridge-hub-rococo/src/weights/xcm/pallet_xcm_benchmarks_generic.rs
+++ b/cumulus/parachains/runtimes/bridge-hubs/bridge-hub-rococo/src/weights/xcm/pallet_xcm_benchmarks_generic.rs
@@ -17,9 +17,9 @@
 //! Autogenerated weights for `pallet_xcm_benchmarks::generic`
 //!
 //! THIS FILE WAS AUTO-GENERATED USING THE SUBSTRATE BENCHMARK CLI VERSION 4.0.0-dev
-//! DATE: 2023-11-29, STEPS: `50`, REPEAT: `20`, LOW RANGE: `[]`, HIGH RANGE: `[]`
+//! DATE: 2023-12-12, STEPS: `50`, REPEAT: `20`, LOW RANGE: `[]`, HIGH RANGE: `[]`
 //! WORST CASE MAP SIZE: `1000000`
-//! HOSTNAME: `runner-r43aesjn-project-674-concurrent-0`, CPU: `Intel(R) Xeon(R) CPU @ 2.60GHz`
+//! HOSTNAME: `runner-itmxxexx-project-674-concurrent-0`, CPU: `Intel(R) Xeon(R) CPU @ 2.60GHz`
 //! WASM-EXECUTION: Compiled, CHAIN: Some("bridge-hub-rococo-dev"), DB CACHE: 1024
 
 // Executed Command:
@@ -68,8 +68,8 @@ impl<T: frame_system::Config> WeightInfo<T> {
 		// Proof Size summary in bytes:
 		//  Measured:  `171`
 		//  Estimated: `6196`
-		// Minimum execution time: 61_049_000 picoseconds.
-		Weight::from_parts(62_672_000, 6196)
+		// Minimum execution time: 61_813_000 picoseconds.
+		Weight::from_parts(62_996_000, 6196)
 			.saturating_add(T::DbWeight::get().reads(9))
 			.saturating_add(T::DbWeight::get().writes(4))
 	}
@@ -77,8 +77,8 @@ impl<T: frame_system::Config> WeightInfo<T> {
 		// Proof Size summary in bytes:
 		//  Measured:  `0`
 		//  Estimated: `0`
-		// Minimum execution time: 1_972_000 picoseconds.
-		Weight::from_parts(2_095_000, 0)
+		// Minimum execution time: 2_044_000 picoseconds.
+		Weight::from_parts(2_112_000, 0)
 	}
 	// Storage: `PolkadotXcm::Queries` (r:1 w:0)
 	// Proof: `PolkadotXcm::Queries` (`max_values`: None, `max_size`: None, mode: `Measured`)
@@ -86,58 +86,58 @@ impl<T: frame_system::Config> WeightInfo<T> {
 		// Proof Size summary in bytes:
 		//  Measured:  `32`
 		//  Estimated: `3497`
-		// Minimum execution time: 7_541_000 picoseconds.
-		Weight::from_parts(7_875_000, 3497)
+		// Minimum execution time: 7_472_000 picoseconds.
+		Weight::from_parts(7_723_000, 3497)
 			.saturating_add(T::DbWeight::get().reads(1))
 	}
 	pub fn transact() -> Weight {
 		// Proof Size summary in bytes:
 		//  Measured:  `0`
 		//  Estimated: `0`
-		// Minimum execution time: 8_467_000 picoseconds.
-		Weight::from_parts(8_653_000, 0)
+		// Minimum execution time: 8_414_000 picoseconds.
+		Weight::from_parts(8_765_000, 0)
 	}
 	pub fn refund_surplus() -> Weight {
 		// Proof Size summary in bytes:
 		//  Measured:  `0`
 		//  Estimated: `0`
-		// Minimum execution time: 2_141_000 picoseconds.
-		Weight::from_parts(2_231_000, 0)
+		// Minimum execution time: 2_192_000 picoseconds.
+		Weight::from_parts(2_243_000, 0)
 	}
 	pub fn set_error_handler() -> Weight {
 		// Proof Size summary in bytes:
 		//  Measured:  `0`
 		//  Estimated: `0`
-		// Minimum execution time: 1_881_000 picoseconds.
-		Weight::from_parts(1_941_000, 0)
+		// Minimum execution time: 1_866_000 picoseconds.
+		Weight::from_parts(1_931_000, 0)
 	}
 	pub fn set_appendix() -> Weight {
 		// Proof Size summary in bytes:
 		//  Measured:  `0`
 		//  Estimated: `0`
-		// Minimum execution time: 1_846_000 picoseconds.
-		Weight::from_parts(1_916_000, 0)
+		// Minimum execution time: 1_847_000 picoseconds.
+		Weight::from_parts(1_921_000, 0)
 	}
 	pub fn clear_error() -> Weight {
 		// Proof Size summary in bytes:
 		//  Measured:  `0`
 		//  Estimated: `0`
-		// Minimum execution time: 1_857_000 picoseconds.
-		Weight::from_parts(1_910_000, 0)
+		// Minimum execution time: 1_797_000 picoseconds.
+		Weight::from_parts(1_880_000, 0)
 	}
 	pub fn descend_origin() -> Weight {
 		// Proof Size summary in bytes:
 		//  Measured:  `0`
 		//  Estimated: `0`
-		// Minimum execution time: 2_493_000 picoseconds.
-		Weight::from_parts(2_570_000, 0)
+		// Minimum execution time: 2_458_000 picoseconds.
+		Weight::from_parts(2_523_000, 0)
 	}
 	pub fn clear_origin() -> Weight {
 		// Proof Size summary in bytes:
 		//  Measured:  `0`
 		//  Estimated: `0`
-		// Minimum execution time: 1_857_000 picoseconds.
-		Weight::from_parts(1_930_000, 0)
+		// Minimum execution time: 1_833_000 picoseconds.
+		Weight::from_parts(1_906_000, 0)
 	}
 	// Storage: `ParachainInfo::ParachainId` (r:1 w:0)
 	// Proof: `ParachainInfo::ParachainId` (`max_values`: Some(1), `max_size`: Some(4), added: 499, mode: `MaxEncodedLen`)
@@ -159,8 +159,8 @@ impl<T: frame_system::Config> WeightInfo<T> {
 		// Proof Size summary in bytes:
 		//  Measured:  `171`
 		//  Estimated: `6196`
-		// Minimum execution time: 54_805_000 picoseconds.
-		Weight::from_parts(55_690_000, 6196)
+		// Minimum execution time: 54_659_000 picoseconds.
+		Weight::from_parts(56_025_000, 6196)
 			.saturating_add(T::DbWeight::get().reads(9))
 			.saturating_add(T::DbWeight::get().writes(4))
 	}
@@ -170,8 +170,8 @@ impl<T: frame_system::Config> WeightInfo<T> {
 		// Proof Size summary in bytes:
 		//  Measured:  `90`
 		//  Estimated: `3555`
-		// Minimum execution time: 11_062_000 picoseconds.
-		Weight::from_parts(11_505_000, 3555)
+		// Minimum execution time: 10_953_000 picoseconds.
+		Weight::from_parts(11_220_000, 3555)
 			.saturating_add(T::DbWeight::get().reads(1))
 			.saturating_add(T::DbWeight::get().writes(1))
 	}
@@ -179,8 +179,8 @@ impl<T: frame_system::Config> WeightInfo<T> {
 		// Proof Size summary in bytes:
 		//  Measured:  `0`
 		//  Estimated: `0`
-		// Minimum execution time: 1_873_000 picoseconds.
-		Weight::from_parts(1_962_000, 0)
+		// Minimum execution time: 1_834_000 picoseconds.
+		Weight::from_parts(1_892_000, 0)
 	}
 	// Storage: `PolkadotXcm::VersionNotifyTargets` (r:1 w:1)
 	// Proof: `PolkadotXcm::VersionNotifyTargets` (`max_values`: None, `max_size`: None, mode: `Measured`)
@@ -200,8 +200,8 @@ impl<T: frame_system::Config> WeightInfo<T> {
 		// Proof Size summary in bytes:
 		//  Measured:  `38`
 		//  Estimated: `3503`
-		// Minimum execution time: 22_356_000 picoseconds.
-		Weight::from_parts(23_066_000, 3503)
+		// Minimum execution time: 22_238_000 picoseconds.
+		Weight::from_parts(22_690_000, 3503)
 			.saturating_add(T::DbWeight::get().reads(7))
 			.saturating_add(T::DbWeight::get().writes(3))
 	}
@@ -211,44 +211,44 @@ impl<T: frame_system::Config> WeightInfo<T> {
 		// Proof Size summary in bytes:
 		//  Measured:  `0`
 		//  Estimated: `0`
-		// Minimum execution time: 3_819_000 picoseconds.
-		Weight::from_parts(3_992_000, 0)
+		// Minimum execution time: 3_798_000 picoseconds.
+		Weight::from_parts(3_936_000, 0)
 			.saturating_add(T::DbWeight::get().writes(1))
 	}
 	pub fn burn_asset() -> Weight {
 		// Proof Size summary in bytes:
 		//  Measured:  `0`
 		//  Estimated: `0`
-		// Minimum execution time: 3_033_000 picoseconds.
-		Weight::from_parts(3_157_000, 0)
+		// Minimum execution time: 2_985_000 picoseconds.
+		Weight::from_parts(3_099_000, 0)
 	}
 	pub fn expect_asset() -> Weight {
 		// Proof Size summary in bytes:
 		//  Measured:  `0`
 		//  Estimated: `0`
-		// Minimum execution time: 1_994_000 picoseconds.
-		Weight::from_parts(2_056_000, 0)
+		// Minimum execution time: 1_955_000 picoseconds.
+		Weight::from_parts(2_050_000, 0)
 	}
 	pub fn expect_origin() -> Weight {
 		// Proof Size summary in bytes:
 		//  Measured:  `0`
 		//  Estimated: `0`
-		// Minimum execution time: 1_978_000 picoseconds.
-		Weight::from_parts(2_069_000, 0)
+		// Minimum execution time: 1_939_000 picoseconds.
+		Weight::from_parts(1_990_000, 0)
 	}
 	pub fn expect_error() -> Weight {
 		// Proof Size summary in bytes:
 		//  Measured:  `0`
 		//  Estimated: `0`
-		// Minimum execution time: 1_894_000 picoseconds.
-		Weight::from_parts(1_977_000, 0)
+		// Minimum execution time: 1_841_000 picoseconds.
+		Weight::from_parts(1_900_000, 0)
 	}
 	pub fn expect_transact_status() -> Weight {
 		// Proof Size summary in bytes:
 		//  Measured:  `0`
 		//  Estimated: `0`
-		// Minimum execution time: 2_114_000 picoseconds.
-		Weight::from_parts(2_223_000, 0)
+		// Minimum execution time: 2_081_000 picoseconds.
+		Weight::from_parts(2_145_000, 0)
 	}
 	// Storage: `ParachainInfo::ParachainId` (r:1 w:0)
 	// Proof: `ParachainInfo::ParachainId` (`max_values`: Some(1), `max_size`: Some(4), added: 499, mode: `MaxEncodedLen`)
@@ -270,8 +270,8 @@ impl<T: frame_system::Config> WeightInfo<T> {
 		// Proof Size summary in bytes:
 		//  Measured:  `171`
 		//  Estimated: `6196`
-		// Minimum execution time: 58_704_000 picoseconds.
-		Weight::from_parts(59_677_000, 6196)
+		// Minimum execution time: 59_600_000 picoseconds.
+		Weight::from_parts(61_572_000, 6196)
 			.saturating_add(T::DbWeight::get().reads(9))
 			.saturating_add(T::DbWeight::get().writes(4))
 	}
@@ -279,8 +279,8 @@ impl<T: frame_system::Config> WeightInfo<T> {
 		// Proof Size summary in bytes:
 		//  Measured:  `0`
 		//  Estimated: `0`
-		// Minimum execution time: 4_506_000 picoseconds.
-		Weight::from_parts(4_672_000, 0)
+		// Minimum execution time: 4_390_000 picoseconds.
+		Weight::from_parts(4_517_000, 0)
 	}
 	// Storage: `ParachainInfo::ParachainId` (r:1 w:0)
 	// Proof: `ParachainInfo::ParachainId` (`max_values`: Some(1), `max_size`: Some(4), added: 499, mode: `MaxEncodedLen`)
@@ -302,8 +302,8 @@ impl<T: frame_system::Config> WeightInfo<T> {
 		// Proof Size summary in bytes:
 		//  Measured:  `171`
 		//  Estimated: `6196`
-		// Minimum execution time: 54_896_000 picoseconds.
-		Weight::from_parts(56_331_000, 6196)
+		// Minimum execution time: 53_864_000 picoseconds.
+		Weight::from_parts(55_527_000, 6196)
 			.saturating_add(T::DbWeight::get().reads(9))
 			.saturating_add(T::DbWeight::get().writes(4))
 	}
@@ -311,29 +311,27 @@ impl<T: frame_system::Config> WeightInfo<T> {
 		// Proof Size summary in bytes:
 		//  Measured:  `0`
 		//  Estimated: `0`
-		// Minimum execution time: 1_946_000 picoseconds.
-		Weight::from_parts(2_002_000, 0)
+		// Minimum execution time: 1_879_000 picoseconds.
+		Weight::from_parts(1_947_000, 0)
 	}
 	pub fn set_topic() -> Weight {
 		// Proof Size summary in bytes:
 		//  Measured:  `0`
 		//  Estimated: `0`
-		// Minimum execution time: 1_898_000 picoseconds.
-		Weight::from_parts(1_961_000, 0)
+		// Minimum execution time: 1_827_000 picoseconds.
+		Weight::from_parts(1_900_000, 0)
 	}
 	pub fn clear_topic() -> Weight {
 		// Proof Size summary in bytes:
 		//  Measured:  `0`
 		//  Estimated: `0`
-		// Minimum execution time: 1_895_000 picoseconds.
-		Weight::from_parts(1_964_000, 0)
+		// Minimum execution time: 1_824_000 picoseconds.
+		Weight::from_parts(1_898_000, 0)
 	}
 	// Storage: `ParachainInfo::ParachainId` (r:1 w:0)
 	// Proof: `ParachainInfo::ParachainId` (`max_values`: Some(1), `max_size`: Some(4), added: 499, mode: `MaxEncodedLen`)
 	// Storage: `PolkadotXcm::SupportedVersion` (r:2 w:0)
 	// Proof: `PolkadotXcm::SupportedVersion` (`max_values`: None, `max_size`: None, mode: `Measured`)
-	// Storage: `PolkadotXcm::VersionDiscoveryQueue` (r:1 w:1)
-	// Proof: `PolkadotXcm::VersionDiscoveryQueue` (`max_values`: Some(1), `max_size`: None, mode: `Measured`)
 	// Storage: `BridgeWestendMessages::PalletOperatingMode` (r:1 w:0)
 	// Proof: `BridgeWestendMessages::PalletOperatingMode` (`max_values`: Some(1), `max_size`: Some(2), added: 497, mode: `MaxEncodedLen`)
 	// Storage: `BridgeWestendMessages::OutboundLanes` (r:1 w:1)
@@ -347,25 +345,25 @@ impl<T: frame_system::Config> WeightInfo<T> {
 		// Proof Size summary in bytes:
 		//  Measured:  `190`
 		//  Estimated: `6130`
-		// Minimum execution time: 36_547_000 picoseconds.
-		Weight::from_parts(37_623_117, 6130)
-			// Standard Error: 735
-			.saturating_add(Weight::from_parts(315_274, 0).saturating_mul(x.into()))
-			.saturating_add(T::DbWeight::get().reads(7))
-			.saturating_add(T::DbWeight::get().writes(3))
+		// Minimum execution time: 41_598_000 picoseconds.
+		Weight::from_parts(42_219_173, 6130)
+			// Standard Error: 426
+			.saturating_add(Weight::from_parts(452_460, 0).saturating_mul(x.into()))
+			.saturating_add(T::DbWeight::get().reads(6))
+			.saturating_add(T::DbWeight::get().writes(2))
 	}
 	pub fn set_fees_mode() -> Weight {
 		// Proof Size summary in bytes:
 		//  Measured:  `0`
 		//  Estimated: `0`
-		// Minimum execution time: 1_868_000 picoseconds.
-		Weight::from_parts(1_910_000, 0)
+		// Minimum execution time: 1_812_000 picoseconds.
+		Weight::from_parts(1_898_000, 0)
 	}
 	pub fn unpaid_execution() -> Weight {
 		// Proof Size summary in bytes:
 		//  Measured:  `0`
 		//  Estimated: `0`
-		// Minimum execution time: 1_998_000 picoseconds.
-		Weight::from_parts(2_069_000, 0)
+		// Minimum execution time: 1_915_000 picoseconds.
+		Weight::from_parts(1_976_000, 0)
 	}
 }
diff --git a/cumulus/parachains/runtimes/bridge-hubs/bridge-hub-westend/src/weights/pallet_bridge_grandpa.rs b/cumulus/parachains/runtimes/bridge-hubs/bridge-hub-westend/src/weights/pallet_bridge_grandpa.rs
index b0634ff2ccf..e87ed668dfc 100644
--- a/cumulus/parachains/runtimes/bridge-hubs/bridge-hub-westend/src/weights/pallet_bridge_grandpa.rs
+++ b/cumulus/parachains/runtimes/bridge-hubs/bridge-hub-westend/src/weights/pallet_bridge_grandpa.rs
@@ -17,10 +17,10 @@
 //! Autogenerated weights for `pallet_bridge_grandpa`
 //!
 //! THIS FILE WAS AUTO-GENERATED USING THE SUBSTRATE BENCHMARK CLI VERSION 4.0.0-dev
-//! DATE: 2023-10-27, STEPS: `50`, REPEAT: `20`, LOW RANGE: `[]`, HIGH RANGE: `[]`
+//! DATE: 2023-12-13, STEPS: `50`, REPEAT: `20`, LOW RANGE: `[]`, HIGH RANGE: `[]`
 //! WORST CASE MAP SIZE: `1000000`
-//! HOSTNAME: `runner-vmdtonbz-project-674-concurrent-0`, CPU: `Intel(R) Xeon(R) CPU @ 2.60GHz`
-//! WASM-EXECUTION: `Compiled`, CHAIN: `Some("bridge-hub-rococo-dev")`, DB CACHE: 1024
+//! HOSTNAME: `runner-itmxxexx-project-674-concurrent-0`, CPU: `Intel(R) Xeon(R) CPU @ 2.60GHz`
+//! WASM-EXECUTION: `Compiled`, CHAIN: `Some("bridge-hub-westend-dev")`, DB CACHE: 1024
 
 // Executed Command:
 // target/production/polkadot-parachain
@@ -33,9 +33,9 @@
 // --heap-pages=4096
 // --json-file=/builds/parity/mirrors/polkadot-sdk/.git/.artifacts/bench.json
 // --pallet=pallet_bridge_grandpa
-// --chain=bridge-hub-rococo-dev
+// --chain=bridge-hub-westend-dev
 // --header=./cumulus/file_header.txt
-// --output=./cumulus/parachains/runtimes/bridge-hubs/bridge-hub-rococo/src/weights/
+// --output=./cumulus/parachains/runtimes/bridge-hubs/bridge-hub-westend/src/weights/
 
 #![cfg_attr(rustfmt, rustfmt_skip)]
 #![allow(unused_parens)]
@@ -62,21 +62,17 @@ impl<T: frame_system::Config> pallet_bridge_grandpa::WeightInfo for WeightInfo<T
 	/// Proof: `BridgeRococoGrandpa::ImportedHeaders` (`max_values`: Some(1024), `max_size`: Some(68), added: 1553, mode: `MaxEncodedLen`)
 	/// The range of component `p` is `[1, 838]`.
 	/// The range of component `v` is `[50, 100]`.
-	/// The range of component `p` is `[1, 838]`.
-	/// The range of component `v` is `[50, 100]`.
-	/// The range of component `p` is `[1, 838]`.
-	/// The range of component `v` is `[50, 100]`.
 	fn submit_finality_proof(p: u32, v: u32, ) -> Weight {
 		// Proof Size summary in bytes:
-		//  Measured:  `268 + p * (60 ±0)`
+		//  Measured:  `231 + p * (60 ±0)`
 		//  Estimated: `51735`
-		// Minimum execution time: 304_726_000 picoseconds.
-		Weight::from_parts(16_868_060, 0)
+		// Minimum execution time: 303_549_000 picoseconds.
+		Weight::from_parts(306_232_000, 0)
 			.saturating_add(Weight::from_parts(0, 51735))
-			// Standard Error: 2_802
-			.saturating_add(Weight::from_parts(55_200_017, 0).saturating_mul(p.into()))
-			// Standard Error: 46_745
-			.saturating_add(Weight::from_parts(2_689_151, 0).saturating_mul(v.into()))
+			// Standard Error: 4_641
+			.saturating_add(Weight::from_parts(55_196_301, 0).saturating_mul(p.into()))
+			// Standard Error: 35_813
+			.saturating_add(Weight::from_parts(70_584, 0).saturating_mul(v.into()))
 			.saturating_add(T::DbWeight::get().reads(5))
 			.saturating_add(T::DbWeight::get().writes(5))
 	}
diff --git a/cumulus/parachains/runtimes/bridge-hubs/bridge-hub-westend/src/weights/pallet_bridge_messages.rs b/cumulus/parachains/runtimes/bridge-hubs/bridge-hub-westend/src/weights/pallet_bridge_messages.rs
index 5d229497f3e..305a8726fa1 100644
--- a/cumulus/parachains/runtimes/bridge-hubs/bridge-hub-westend/src/weights/pallet_bridge_messages.rs
+++ b/cumulus/parachains/runtimes/bridge-hubs/bridge-hub-westend/src/weights/pallet_bridge_messages.rs
@@ -17,10 +17,10 @@
 //! Autogenerated weights for `pallet_bridge_messages`
 //!
 //! THIS FILE WAS AUTO-GENERATED USING THE SUBSTRATE BENCHMARK CLI VERSION 4.0.0-dev
-//! DATE: 2023-10-26, STEPS: `50`, REPEAT: `20`, LOW RANGE: `[]`, HIGH RANGE: `[]`
+//! DATE: 2023-12-13, STEPS: `50`, REPEAT: `20`, LOW RANGE: `[]`, HIGH RANGE: `[]`
 //! WORST CASE MAP SIZE: `1000000`
-//! HOSTNAME: `runner-vmdtonbz-project-674-concurrent-0`, CPU: `Intel(R) Xeon(R) CPU @ 2.60GHz`
-//! WASM-EXECUTION: `Compiled`, CHAIN: `Some("bridge-hub-rococo-dev")`, DB CACHE: 1024
+//! HOSTNAME: `runner-itmxxexx-project-674-concurrent-0`, CPU: `Intel(R) Xeon(R) CPU @ 2.60GHz`
+//! WASM-EXECUTION: `Compiled`, CHAIN: `Some("bridge-hub-westend-dev")`, DB CACHE: 1024
 
 // Executed Command:
 // target/production/polkadot-parachain
@@ -33,9 +33,9 @@
 // --heap-pages=4096
 // --json-file=/builds/parity/mirrors/polkadot-sdk/.git/.artifacts/bench.json
 // --pallet=pallet_bridge_messages
-// --chain=bridge-hub-rococo-dev
+// --chain=bridge-hub-westend-dev
 // --header=./cumulus/file_header.txt
-// --output=./cumulus/parachains/runtimes/bridge-hubs/bridge-hub-rococo/src/weights/
+// --output=./cumulus/parachains/runtimes/bridge-hubs/bridge-hub-westend/src/weights/
 
 #![cfg_attr(rustfmt, rustfmt_skip)]
 #![allow(unused_parens)]
@@ -48,170 +48,170 @@ use core::marker::PhantomData;
 /// Weight functions for `pallet_bridge_messages`.
 pub struct WeightInfo<T>(PhantomData<T>);
 impl<T: frame_system::Config> pallet_bridge_messages::WeightInfo for WeightInfo<T> {
-	/// Storage: `BridgeWestendToRococoMessages::PalletOperatingMode` (r:1 w:0)
-	/// Proof: `BridgeWestendToRococoMessages::PalletOperatingMode` (`max_values`: Some(1), `max_size`: Some(2), added: 497, mode: `MaxEncodedLen`)
+	/// Storage: `BridgeRococoMessages::PalletOperatingMode` (r:1 w:0)
+	/// Proof: `BridgeRococoMessages::PalletOperatingMode` (`max_values`: Some(1), `max_size`: Some(2), added: 497, mode: `MaxEncodedLen`)
 	/// Storage: `XcmpQueue::OutboundXcmpStatus` (r:1 w:0)
 	/// Proof: `XcmpQueue::OutboundXcmpStatus` (`max_values`: Some(1), `max_size`: None, mode: `Measured`)
-	/// Storage: `BridgeRococoParachain::ImportedParaHeads` (r:1 w:0)
-	/// Proof: `BridgeRococoParachain::ImportedParaHeads` (`max_values`: Some(64), `max_size`: Some(196), added: 1186, mode: `MaxEncodedLen`)
-	/// Storage: `BridgeWestendToRococoMessages::InboundLanes` (r:1 w:1)
-	/// Proof: `BridgeWestendToRococoMessages::InboundLanes` (`max_values`: None, `max_size`: Some(49180), added: 51655, mode: `MaxEncodedLen`)
+	/// Storage: `BridgeRococoParachains::ImportedParaHeads` (r:1 w:0)
+	/// Proof: `BridgeRococoParachains::ImportedParaHeads` (`max_values`: Some(64), `max_size`: Some(196), added: 1186, mode: `MaxEncodedLen`)
+	/// Storage: `BridgeRococoMessages::InboundLanes` (r:1 w:1)
+	/// Proof: `BridgeRococoMessages::InboundLanes` (`max_values`: None, `max_size`: Some(49180), added: 51655, mode: `MaxEncodedLen`)
 	/// Storage: `ParachainInfo::ParachainId` (r:1 w:0)
 	/// Proof: `ParachainInfo::ParachainId` (`max_values`: Some(1), `max_size`: Some(4), added: 499, mode: `MaxEncodedLen`)
 	fn receive_single_message_proof() -> Weight {
 		// Proof Size summary in bytes:
-		//  Measured:  `575`
+		//  Measured:  `502`
 		//  Estimated: `52645`
-		// Minimum execution time: 42_332_000 picoseconds.
-		Weight::from_parts(43_375_000, 0)
+		// Minimum execution time: 40_646_000 picoseconds.
+		Weight::from_parts(41_754_000, 0)
 			.saturating_add(Weight::from_parts(0, 52645))
 			.saturating_add(T::DbWeight::get().reads(5))
 			.saturating_add(T::DbWeight::get().writes(1))
 	}
-	/// Storage: `BridgeWestendToRococoMessages::PalletOperatingMode` (r:1 w:0)
-	/// Proof: `BridgeWestendToRococoMessages::PalletOperatingMode` (`max_values`: Some(1), `max_size`: Some(2), added: 497, mode: `MaxEncodedLen`)
+	/// Storage: `BridgeRococoMessages::PalletOperatingMode` (r:1 w:0)
+	/// Proof: `BridgeRococoMessages::PalletOperatingMode` (`max_values`: Some(1), `max_size`: Some(2), added: 497, mode: `MaxEncodedLen`)
 	/// Storage: `XcmpQueue::OutboundXcmpStatus` (r:1 w:0)
 	/// Proof: `XcmpQueue::OutboundXcmpStatus` (`max_values`: Some(1), `max_size`: None, mode: `Measured`)
-	/// Storage: `BridgeRococoParachain::ImportedParaHeads` (r:1 w:0)
-	/// Proof: `BridgeRococoParachain::ImportedParaHeads` (`max_values`: Some(64), `max_size`: Some(196), added: 1186, mode: `MaxEncodedLen`)
-	/// Storage: `BridgeWestendToRococoMessages::InboundLanes` (r:1 w:1)
-	/// Proof: `BridgeWestendToRococoMessages::InboundLanes` (`max_values`: None, `max_size`: Some(49180), added: 51655, mode: `MaxEncodedLen`)
+	/// Storage: `BridgeRococoParachains::ImportedParaHeads` (r:1 w:0)
+	/// Proof: `BridgeRococoParachains::ImportedParaHeads` (`max_values`: Some(64), `max_size`: Some(196), added: 1186, mode: `MaxEncodedLen`)
+	/// Storage: `BridgeRococoMessages::InboundLanes` (r:1 w:1)
+	/// Proof: `BridgeRococoMessages::InboundLanes` (`max_values`: None, `max_size`: Some(49180), added: 51655, mode: `MaxEncodedLen`)
 	/// Storage: `ParachainInfo::ParachainId` (r:1 w:0)
 	/// Proof: `ParachainInfo::ParachainId` (`max_values`: Some(1), `max_size`: Some(4), added: 499, mode: `MaxEncodedLen`)
 	fn receive_two_messages_proof() -> Weight {
 		// Proof Size summary in bytes:
-		//  Measured:  `575`
+		//  Measured:  `502`
 		//  Estimated: `52645`
-		// Minimum execution time: 53_139_000 picoseconds.
-		Weight::from_parts(54_236_000, 0)
+		// Minimum execution time: 50_898_000 picoseconds.
+		Weight::from_parts(52_743_000, 0)
 			.saturating_add(Weight::from_parts(0, 52645))
 			.saturating_add(T::DbWeight::get().reads(5))
 			.saturating_add(T::DbWeight::get().writes(1))
 	}
-	/// Storage: `BridgeWestendToRococoMessages::PalletOperatingMode` (r:1 w:0)
-	/// Proof: `BridgeWestendToRococoMessages::PalletOperatingMode` (`max_values`: Some(1), `max_size`: Some(2), added: 497, mode: `MaxEncodedLen`)
+	/// Storage: `BridgeRococoMessages::PalletOperatingMode` (r:1 w:0)
+	/// Proof: `BridgeRococoMessages::PalletOperatingMode` (`max_values`: Some(1), `max_size`: Some(2), added: 497, mode: `MaxEncodedLen`)
 	/// Storage: `XcmpQueue::OutboundXcmpStatus` (r:1 w:0)
 	/// Proof: `XcmpQueue::OutboundXcmpStatus` (`max_values`: Some(1), `max_size`: None, mode: `Measured`)
-	/// Storage: `BridgeRococoParachain::ImportedParaHeads` (r:1 w:0)
-	/// Proof: `BridgeRococoParachain::ImportedParaHeads` (`max_values`: Some(64), `max_size`: Some(196), added: 1186, mode: `MaxEncodedLen`)
-	/// Storage: `BridgeWestendToRococoMessages::InboundLanes` (r:1 w:1)
-	/// Proof: `BridgeWestendToRococoMessages::InboundLanes` (`max_values`: None, `max_size`: Some(49180), added: 51655, mode: `MaxEncodedLen`)
+	/// Storage: `BridgeRococoParachains::ImportedParaHeads` (r:1 w:0)
+	/// Proof: `BridgeRococoParachains::ImportedParaHeads` (`max_values`: Some(64), `max_size`: Some(196), added: 1186, mode: `MaxEncodedLen`)
+	/// Storage: `BridgeRococoMessages::InboundLanes` (r:1 w:1)
+	/// Proof: `BridgeRococoMessages::InboundLanes` (`max_values`: None, `max_size`: Some(49180), added: 51655, mode: `MaxEncodedLen`)
 	/// Storage: `ParachainInfo::ParachainId` (r:1 w:0)
 	/// Proof: `ParachainInfo::ParachainId` (`max_values`: Some(1), `max_size`: Some(4), added: 499, mode: `MaxEncodedLen`)
 	fn receive_single_message_proof_with_outbound_lane_state() -> Weight {
 		// Proof Size summary in bytes:
-		//  Measured:  `575`
+		//  Measured:  `502`
 		//  Estimated: `52645`
-		// Minimum execution time: 47_466_000 picoseconds.
-		Weight::from_parts(48_724_000, 0)
+		// Minimum execution time: 45_848_000 picoseconds.
+		Weight::from_parts(47_036_000, 0)
 			.saturating_add(Weight::from_parts(0, 52645))
 			.saturating_add(T::DbWeight::get().reads(5))
 			.saturating_add(T::DbWeight::get().writes(1))
 	}
-	/// Storage: `BridgeWestendToRococoMessages::PalletOperatingMode` (r:1 w:0)
-	/// Proof: `BridgeWestendToRococoMessages::PalletOperatingMode` (`max_values`: Some(1), `max_size`: Some(2), added: 497, mode: `MaxEncodedLen`)
+	/// Storage: `BridgeRococoMessages::PalletOperatingMode` (r:1 w:0)
+	/// Proof: `BridgeRococoMessages::PalletOperatingMode` (`max_values`: Some(1), `max_size`: Some(2), added: 497, mode: `MaxEncodedLen`)
 	/// Storage: `XcmpQueue::OutboundXcmpStatus` (r:1 w:0)
 	/// Proof: `XcmpQueue::OutboundXcmpStatus` (`max_values`: Some(1), `max_size`: None, mode: `Measured`)
-	/// Storage: `BridgeRococoParachain::ImportedParaHeads` (r:1 w:0)
-	/// Proof: `BridgeRococoParachain::ImportedParaHeads` (`max_values`: Some(64), `max_size`: Some(196), added: 1186, mode: `MaxEncodedLen`)
-	/// Storage: `BridgeWestendToRococoMessages::InboundLanes` (r:1 w:1)
-	/// Proof: `BridgeWestendToRococoMessages::InboundLanes` (`max_values`: None, `max_size`: Some(49180), added: 51655, mode: `MaxEncodedLen`)
+	/// Storage: `BridgeRococoParachains::ImportedParaHeads` (r:1 w:0)
+	/// Proof: `BridgeRococoParachains::ImportedParaHeads` (`max_values`: Some(64), `max_size`: Some(196), added: 1186, mode: `MaxEncodedLen`)
+	/// Storage: `BridgeRococoMessages::InboundLanes` (r:1 w:1)
+	/// Proof: `BridgeRococoMessages::InboundLanes` (`max_values`: None, `max_size`: Some(49180), added: 51655, mode: `MaxEncodedLen`)
 	fn receive_single_message_proof_1_kb() -> Weight {
 		// Proof Size summary in bytes:
-		//  Measured:  `543`
+		//  Measured:  `433`
 		//  Estimated: `52645`
-		// Minimum execution time: 40_962_000 picoseconds.
-		Weight::from_parts(42_002_000, 0)
+		// Minimum execution time: 39_085_000 picoseconds.
+		Weight::from_parts(41_623_000, 0)
 			.saturating_add(Weight::from_parts(0, 52645))
 			.saturating_add(T::DbWeight::get().reads(4))
 			.saturating_add(T::DbWeight::get().writes(1))
 	}
-	/// Storage: `BridgeWestendToRococoMessages::PalletOperatingMode` (r:1 w:0)
-	/// Proof: `BridgeWestendToRococoMessages::PalletOperatingMode` (`max_values`: Some(1), `max_size`: Some(2), added: 497, mode: `MaxEncodedLen`)
+	/// Storage: `BridgeRococoMessages::PalletOperatingMode` (r:1 w:0)
+	/// Proof: `BridgeRococoMessages::PalletOperatingMode` (`max_values`: Some(1), `max_size`: Some(2), added: 497, mode: `MaxEncodedLen`)
 	/// Storage: `XcmpQueue::OutboundXcmpStatus` (r:1 w:0)
 	/// Proof: `XcmpQueue::OutboundXcmpStatus` (`max_values`: Some(1), `max_size`: None, mode: `Measured`)
-	/// Storage: `BridgeRococoParachain::ImportedParaHeads` (r:1 w:0)
-	/// Proof: `BridgeRococoParachain::ImportedParaHeads` (`max_values`: Some(64), `max_size`: Some(196), added: 1186, mode: `MaxEncodedLen`)
-	/// Storage: `BridgeWestendToRococoMessages::InboundLanes` (r:1 w:1)
-	/// Proof: `BridgeWestendToRococoMessages::InboundLanes` (`max_values`: None, `max_size`: Some(49180), added: 51655, mode: `MaxEncodedLen`)
+	/// Storage: `BridgeRococoParachains::ImportedParaHeads` (r:1 w:0)
+	/// Proof: `BridgeRococoParachains::ImportedParaHeads` (`max_values`: Some(64), `max_size`: Some(196), added: 1186, mode: `MaxEncodedLen`)
+	/// Storage: `BridgeRococoMessages::InboundLanes` (r:1 w:1)
+	/// Proof: `BridgeRococoMessages::InboundLanes` (`max_values`: None, `max_size`: Some(49180), added: 51655, mode: `MaxEncodedLen`)
 	fn receive_single_message_proof_16_kb() -> Weight {
 		// Proof Size summary in bytes:
-		//  Measured:  `543`
+		//  Measured:  `433`
 		//  Estimated: `52645`
-		// Minimum execution time: 71_599_000 picoseconds.
-		Weight::from_parts(74_307_000, 0)
+		// Minimum execution time: 72_754_000 picoseconds.
+		Weight::from_parts(74_985_000, 0)
 			.saturating_add(Weight::from_parts(0, 52645))
 			.saturating_add(T::DbWeight::get().reads(4))
 			.saturating_add(T::DbWeight::get().writes(1))
 	}
-	/// Storage: `BridgeWestendToRococoMessages::PalletOperatingMode` (r:1 w:0)
-	/// Proof: `BridgeWestendToRococoMessages::PalletOperatingMode` (`max_values`: Some(1), `max_size`: Some(2), added: 497, mode: `MaxEncodedLen`)
-	/// Storage: `BridgeRococoParachain::ImportedParaHeads` (r:1 w:0)
-	/// Proof: `BridgeRococoParachain::ImportedParaHeads` (`max_values`: Some(64), `max_size`: Some(196), added: 1186, mode: `MaxEncodedLen`)
-	/// Storage: `BridgeWestendToRococoMessages::OutboundLanes` (r:1 w:1)
-	/// Proof: `BridgeWestendToRococoMessages::OutboundLanes` (`max_values`: Some(1), `max_size`: Some(44), added: 539, mode: `MaxEncodedLen`)
+	/// Storage: `BridgeRococoMessages::PalletOperatingMode` (r:1 w:0)
+	/// Proof: `BridgeRococoMessages::PalletOperatingMode` (`max_values`: Some(1), `max_size`: Some(2), added: 497, mode: `MaxEncodedLen`)
+	/// Storage: `BridgeRococoParachains::ImportedParaHeads` (r:1 w:0)
+	/// Proof: `BridgeRococoParachains::ImportedParaHeads` (`max_values`: Some(64), `max_size`: Some(196), added: 1186, mode: `MaxEncodedLen`)
+	/// Storage: `BridgeRococoMessages::OutboundLanes` (r:1 w:1)
+	/// Proof: `BridgeRococoMessages::OutboundLanes` (`max_values`: Some(1), `max_size`: Some(44), added: 539, mode: `MaxEncodedLen`)
 	/// Storage: UNKNOWN KEY `0x6e0a18b62a1de81c5f519181cc611e18` (r:1 w:0)
 	/// Proof: UNKNOWN KEY `0x6e0a18b62a1de81c5f519181cc611e18` (r:1 w:0)
 	/// Storage: `BridgeRelayers::RelayerRewards` (r:1 w:1)
 	/// Proof: `BridgeRelayers::RelayerRewards` (`max_values`: None, `max_size`: Some(73), added: 2548, mode: `MaxEncodedLen`)
 	fn receive_delivery_proof_for_single_message() -> Weight {
 		// Proof Size summary in bytes:
-		//  Measured:  `414`
-		//  Estimated: `3879`
-		// Minimum execution time: 31_206_000 picoseconds.
-		Weight::from_parts(32_045_000, 0)
-			.saturating_add(Weight::from_parts(0, 3879))
+		//  Measured:  `337`
+		//  Estimated: `3802`
+		// Minimum execution time: 31_479_000 picoseconds.
+		Weight::from_parts(32_280_000, 0)
+			.saturating_add(Weight::from_parts(0, 3802))
 			.saturating_add(T::DbWeight::get().reads(5))
 			.saturating_add(T::DbWeight::get().writes(2))
 	}
-	/// Storage: `BridgeWestendToRococoMessages::PalletOperatingMode` (r:1 w:0)
-	/// Proof: `BridgeWestendToRococoMessages::PalletOperatingMode` (`max_values`: Some(1), `max_size`: Some(2), added: 497, mode: `MaxEncodedLen`)
-	/// Storage: `BridgeRococoParachain::ImportedParaHeads` (r:1 w:0)
-	/// Proof: `BridgeRococoParachain::ImportedParaHeads` (`max_values`: Some(64), `max_size`: Some(196), added: 1186, mode: `MaxEncodedLen`)
-	/// Storage: `BridgeWestendToRococoMessages::OutboundLanes` (r:1 w:1)
-	/// Proof: `BridgeWestendToRococoMessages::OutboundLanes` (`max_values`: Some(1), `max_size`: Some(44), added: 539, mode: `MaxEncodedLen`)
+	/// Storage: `BridgeRococoMessages::PalletOperatingMode` (r:1 w:0)
+	/// Proof: `BridgeRococoMessages::PalletOperatingMode` (`max_values`: Some(1), `max_size`: Some(2), added: 497, mode: `MaxEncodedLen`)
+	/// Storage: `BridgeRococoParachains::ImportedParaHeads` (r:1 w:0)
+	/// Proof: `BridgeRococoParachains::ImportedParaHeads` (`max_values`: Some(64), `max_size`: Some(196), added: 1186, mode: `MaxEncodedLen`)
+	/// Storage: `BridgeRococoMessages::OutboundLanes` (r:1 w:1)
+	/// Proof: `BridgeRococoMessages::OutboundLanes` (`max_values`: Some(1), `max_size`: Some(44), added: 539, mode: `MaxEncodedLen`)
 	/// Storage: UNKNOWN KEY `0x6e0a18b62a1de81c5f519181cc611e18` (r:1 w:0)
 	/// Proof: UNKNOWN KEY `0x6e0a18b62a1de81c5f519181cc611e18` (r:1 w:0)
 	/// Storage: `BridgeRelayers::RelayerRewards` (r:1 w:1)
 	/// Proof: `BridgeRelayers::RelayerRewards` (`max_values`: None, `max_size`: Some(73), added: 2548, mode: `MaxEncodedLen`)
 	fn receive_delivery_proof_for_two_messages_by_single_relayer() -> Weight {
 		// Proof Size summary in bytes:
-		//  Measured:  `414`
-		//  Estimated: `3879`
-		// Minimum execution time: 31_211_000 picoseconds.
-		Weight::from_parts(32_171_000, 0)
-			.saturating_add(Weight::from_parts(0, 3879))
+		//  Measured:  `337`
+		//  Estimated: `3802`
+		// Minimum execution time: 31_807_000 picoseconds.
+		Weight::from_parts(32_219_000, 0)
+			.saturating_add(Weight::from_parts(0, 3802))
 			.saturating_add(T::DbWeight::get().reads(5))
 			.saturating_add(T::DbWeight::get().writes(2))
 	}
-	/// Storage: `BridgeWestendToRococoMessages::PalletOperatingMode` (r:1 w:0)
-	/// Proof: `BridgeWestendToRococoMessages::PalletOperatingMode` (`max_values`: Some(1), `max_size`: Some(2), added: 497, mode: `MaxEncodedLen`)
-	/// Storage: `BridgeRococoParachain::ImportedParaHeads` (r:1 w:0)
-	/// Proof: `BridgeRococoParachain::ImportedParaHeads` (`max_values`: Some(64), `max_size`: Some(196), added: 1186, mode: `MaxEncodedLen`)
-	/// Storage: `BridgeWestendToRococoMessages::OutboundLanes` (r:1 w:1)
-	/// Proof: `BridgeWestendToRococoMessages::OutboundLanes` (`max_values`: Some(1), `max_size`: Some(44), added: 539, mode: `MaxEncodedLen`)
+	/// Storage: `BridgeRococoMessages::PalletOperatingMode` (r:1 w:0)
+	/// Proof: `BridgeRococoMessages::PalletOperatingMode` (`max_values`: Some(1), `max_size`: Some(2), added: 497, mode: `MaxEncodedLen`)
+	/// Storage: `BridgeRococoParachains::ImportedParaHeads` (r:1 w:0)
+	/// Proof: `BridgeRococoParachains::ImportedParaHeads` (`max_values`: Some(64), `max_size`: Some(196), added: 1186, mode: `MaxEncodedLen`)
+	/// Storage: `BridgeRococoMessages::OutboundLanes` (r:1 w:1)
+	/// Proof: `BridgeRococoMessages::OutboundLanes` (`max_values`: Some(1), `max_size`: Some(44), added: 539, mode: `MaxEncodedLen`)
 	/// Storage: UNKNOWN KEY `0x6e0a18b62a1de81c5f519181cc611e18` (r:1 w:0)
 	/// Proof: UNKNOWN KEY `0x6e0a18b62a1de81c5f519181cc611e18` (r:1 w:0)
 	/// Storage: `BridgeRelayers::RelayerRewards` (r:2 w:2)
 	/// Proof: `BridgeRelayers::RelayerRewards` (`max_values`: None, `max_size`: Some(73), added: 2548, mode: `MaxEncodedLen`)
 	fn receive_delivery_proof_for_two_messages_by_two_relayers() -> Weight {
 		// Proof Size summary in bytes:
-		//  Measured:  `414`
+		//  Measured:  `337`
 		//  Estimated: `6086`
-		// Minimum execution time: 33_790_000 picoseconds.
-		Weight::from_parts(34_708_000, 0)
+		// Minimum execution time: 36_450_000 picoseconds.
+		Weight::from_parts(37_288_000, 0)
 			.saturating_add(Weight::from_parts(0, 6086))
 			.saturating_add(T::DbWeight::get().reads(6))
 			.saturating_add(T::DbWeight::get().writes(3))
 	}
-	/// Storage: `BridgeWestendToRococoMessages::PalletOperatingMode` (r:1 w:0)
-	/// Proof: `BridgeWestendToRococoMessages::PalletOperatingMode` (`max_values`: Some(1), `max_size`: Some(2), added: 497, mode: `MaxEncodedLen`)
+	/// Storage: `BridgeRococoMessages::PalletOperatingMode` (r:1 w:0)
+	/// Proof: `BridgeRococoMessages::PalletOperatingMode` (`max_values`: Some(1), `max_size`: Some(2), added: 497, mode: `MaxEncodedLen`)
 	/// Storage: `XcmpQueue::OutboundXcmpStatus` (r:1 w:1)
 	/// Proof: `XcmpQueue::OutboundXcmpStatus` (`max_values`: Some(1), `max_size`: None, mode: `Measured`)
-	/// Storage: `BridgeRococoParachain::ImportedParaHeads` (r:1 w:0)
-	/// Proof: `BridgeRococoParachain::ImportedParaHeads` (`max_values`: Some(64), `max_size`: Some(196), added: 1186, mode: `MaxEncodedLen`)
-	/// Storage: `BridgeWestendToRococoMessages::InboundLanes` (r:1 w:1)
-	/// Proof: `BridgeWestendToRococoMessages::InboundLanes` (`max_values`: None, `max_size`: Some(49180), added: 51655, mode: `MaxEncodedLen`)
+	/// Storage: `BridgeRococoParachains::ImportedParaHeads` (r:1 w:0)
+	/// Proof: `BridgeRococoParachains::ImportedParaHeads` (`max_values`: Some(64), `max_size`: Some(196), added: 1186, mode: `MaxEncodedLen`)
+	/// Storage: `BridgeRococoMessages::InboundLanes` (r:1 w:1)
+	/// Proof: `BridgeRococoMessages::InboundLanes` (`max_values`: None, `max_size`: Some(49180), added: 51655, mode: `MaxEncodedLen`)
 	/// Storage: `ParachainInfo::ParachainId` (r:1 w:0)
 	/// Proof: `ParachainInfo::ParachainId` (`max_values`: Some(1), `max_size`: Some(4), added: 499, mode: `MaxEncodedLen`)
 	/// Storage: `XcmpQueue::DeliveryFeeFactor` (r:1 w:0)
@@ -227,18 +227,15 @@ impl<T: frame_system::Config> pallet_bridge_messages::WeightInfo for WeightInfo<
 	/// Storage: `XcmpQueue::OutboundXcmpMessages` (r:0 w:1)
 	/// Proof: `XcmpQueue::OutboundXcmpMessages` (`max_values`: None, `max_size`: None, mode: `Measured`)
 	/// The range of component `i` is `[128, 2048]`.
-	/// The range of component `i` is `[128, 2048]`.
-	/// The range of component `i` is `[128, 2048]`.
-	/// The range of component `i` is `[128, 2048]`.
 	fn receive_single_message_proof_with_dispatch(i: u32, ) -> Weight {
 		// Proof Size summary in bytes:
-		//  Measured:  `777`
+		//  Measured:  `633`
 		//  Estimated: `52645`
-		// Minimum execution time: 61_938_000 picoseconds.
-		Weight::from_parts(63_009_714, 0)
+		// Minimum execution time: 67_047_000 picoseconds.
+		Weight::from_parts(68_717_105, 0)
 			.saturating_add(Weight::from_parts(0, 52645))
-			// Standard Error: 23
-			.saturating_add(Weight::from_parts(6_677, 0).saturating_mul(i.into()))
+			// Standard Error: 138
+			.saturating_add(Weight::from_parts(8_056, 0).saturating_mul(i.into()))
 			.saturating_add(T::DbWeight::get().reads(10))
 			.saturating_add(T::DbWeight::get().writes(4))
 	}
diff --git a/cumulus/parachains/runtimes/bridge-hubs/bridge-hub-westend/src/weights/pallet_bridge_relayers.rs b/cumulus/parachains/runtimes/bridge-hubs/bridge-hub-westend/src/weights/pallet_bridge_relayers.rs
index fde670ab927..ed96f0cd87c 100644
--- a/cumulus/parachains/runtimes/bridge-hubs/bridge-hub-westend/src/weights/pallet_bridge_relayers.rs
+++ b/cumulus/parachains/runtimes/bridge-hubs/bridge-hub-westend/src/weights/pallet_bridge_relayers.rs
@@ -17,10 +17,10 @@
 //! Autogenerated weights for `pallet_bridge_relayers`
 //!
 //! THIS FILE WAS AUTO-GENERATED USING THE SUBSTRATE BENCHMARK CLI VERSION 4.0.0-dev
-//! DATE: 2023-10-26, STEPS: `50`, REPEAT: `20`, LOW RANGE: `[]`, HIGH RANGE: `[]`
+//! DATE: 2023-12-12, STEPS: `50`, REPEAT: `20`, LOW RANGE: `[]`, HIGH RANGE: `[]`
 //! WORST CASE MAP SIZE: `1000000`
-//! HOSTNAME: `runner-vmdtonbz-project-674-concurrent-0`, CPU: `Intel(R) Xeon(R) CPU @ 2.60GHz`
-//! WASM-EXECUTION: `Compiled`, CHAIN: `Some("bridge-hub-rococo-dev")`, DB CACHE: 1024
+//! HOSTNAME: `runner-itmxxexx-project-674-concurrent-0`, CPU: `Intel(R) Xeon(R) CPU @ 2.60GHz`
+//! WASM-EXECUTION: `Compiled`, CHAIN: `Some("bridge-hub-westend-dev")`, DB CACHE: 1024
 
 // Executed Command:
 // target/production/polkadot-parachain
@@ -33,9 +33,9 @@
 // --heap-pages=4096
 // --json-file=/builds/parity/mirrors/polkadot-sdk/.git/.artifacts/bench.json
 // --pallet=pallet_bridge_relayers
-// --chain=bridge-hub-rococo-dev
+// --chain=bridge-hub-westend-dev
 // --header=./cumulus/file_header.txt
-// --output=./cumulus/parachains/runtimes/bridge-hubs/bridge-hub-rococo/src/weights/
+// --output=./cumulus/parachains/runtimes/bridge-hubs/bridge-hub-westend/src/weights/
 
 #![cfg_attr(rustfmt, rustfmt_skip)]
 #![allow(unused_parens)]
@@ -56,8 +56,8 @@ impl<T: frame_system::Config> pallet_bridge_relayers::WeightInfo for WeightInfo<
 		// Proof Size summary in bytes:
 		//  Measured:  `207`
 		//  Estimated: `3593`
-		// Minimum execution time: 45_338_000 picoseconds.
-		Weight::from_parts(45_836_000, 0)
+		// Minimum execution time: 45_732_000 picoseconds.
+		Weight::from_parts(46_282_000, 0)
 			.saturating_add(Weight::from_parts(0, 3593))
 			.saturating_add(T::DbWeight::get().reads(2))
 			.saturating_add(T::DbWeight::get().writes(2))
@@ -72,8 +72,8 @@ impl<T: frame_system::Config> pallet_bridge_relayers::WeightInfo for WeightInfo<
 		// Proof Size summary in bytes:
 		//  Measured:  `61`
 		//  Estimated: `4714`
-		// Minimum execution time: 23_561_000 picoseconds.
-		Weight::from_parts(24_012_000, 0)
+		// Minimum execution time: 22_934_000 picoseconds.
+		Weight::from_parts(23_531_000, 0)
 			.saturating_add(Weight::from_parts(0, 4714))
 			.saturating_add(T::DbWeight::get().reads(3))
 			.saturating_add(T::DbWeight::get().writes(2))
@@ -86,8 +86,8 @@ impl<T: frame_system::Config> pallet_bridge_relayers::WeightInfo for WeightInfo<
 		// Proof Size summary in bytes:
 		//  Measured:  `160`
 		//  Estimated: `4714`
-		// Minimum execution time: 25_133_000 picoseconds.
-		Weight::from_parts(25_728_000, 0)
+		// Minimum execution time: 25_187_000 picoseconds.
+		Weight::from_parts(25_679_000, 0)
 			.saturating_add(Weight::from_parts(0, 4714))
 			.saturating_add(T::DbWeight::get().reads(2))
 			.saturating_add(T::DbWeight::get().writes(2))
@@ -102,8 +102,8 @@ impl<T: frame_system::Config> pallet_bridge_relayers::WeightInfo for WeightInfo<
 		// Proof Size summary in bytes:
 		//  Measured:  `263`
 		//  Estimated: `4714`
-		// Minimum execution time: 27_356_000 picoseconds.
-		Weight::from_parts(27_828_000, 0)
+		// Minimum execution time: 27_015_000 picoseconds.
+		Weight::from_parts(27_608_000, 0)
 			.saturating_add(Weight::from_parts(0, 4714))
 			.saturating_add(T::DbWeight::get().reads(3))
 			.saturating_add(T::DbWeight::get().writes(3))
@@ -114,8 +114,8 @@ impl<T: frame_system::Config> pallet_bridge_relayers::WeightInfo for WeightInfo<
 		// Proof Size summary in bytes:
 		//  Measured:  `6`
 		//  Estimated: `3538`
-		// Minimum execution time: 2_955_000 picoseconds.
-		Weight::from_parts(3_084_000, 0)
+		// Minimum execution time: 5_207_000 picoseconds.
+		Weight::from_parts(5_394_000, 0)
 			.saturating_add(Weight::from_parts(0, 3538))
 			.saturating_add(T::DbWeight::get().reads(1))
 			.saturating_add(T::DbWeight::get().writes(1))
diff --git a/cumulus/parachains/runtimes/bridge-hubs/bridge-hub-rococo/src/weights/pallet_bridge_messages.rs b/cumulus/parachains/runtimes/bridge-hubs/bridge-hub-rococo/src/weights/pallet_bridge_messages.rs
index 17a45df5bfb..b887f855f01 100644
--- a/cumulus/parachains/runtimes/bridge-hubs/bridge-hub-rococo/src/weights/pallet_bridge_messages.rs
+++ b/cumulus/parachains/runtimes/bridge-hubs/bridge-hub-rococo/src/weights/pallet_bridge_messages.rs
@@ -17,9 +17,9 @@
 //! Autogenerated weights for `pallet_bridge_messages`
 //!
 //! THIS FILE WAS AUTO-GENERATED USING THE SUBSTRATE BENCHMARK CLI VERSION 4.0.0-dev
-//! DATE: 2023-11-14, STEPS: `50`, REPEAT: `20`, LOW RANGE: `[]`, HIGH RANGE: `[]`
+//! DATE: 2023-12-12, STEPS: `50`, REPEAT: `20`, LOW RANGE: `[]`, HIGH RANGE: `[]`
 //! WORST CASE MAP SIZE: `1000000`
-//! HOSTNAME: `runner-yprdrvc7-project-674-concurrent-0`, CPU: `Intel(R) Xeon(R) CPU @ 2.60GHz`
+//! HOSTNAME: `runner-itmxxexx-project-674-concurrent-0`, CPU: `Intel(R) Xeon(R) CPU @ 2.60GHz`
 //! WASM-EXECUTION: `Compiled`, CHAIN: `Some("bridge-hub-rococo-dev")`, DB CACHE: 1024
 
 // Executed Command:
@@ -62,8 +62,8 @@ impl<T: frame_system::Config> pallet_bridge_messages::WeightInfo for WeightInfo<
 		// Proof Size summary in bytes:
 		//  Measured:  `538`
 		//  Estimated: `52645`
-		// Minimum execution time: 41_577_000 picoseconds.
-		Weight::from_parts(42_621_000, 0)
+		// Minimum execution time: 39_918_000 picoseconds.
+		Weight::from_parts(40_996_000, 0)
 			.saturating_add(Weight::from_parts(0, 52645))
 			.saturating_add(T::DbWeight::get().reads(5))
 			.saturating_add(T::DbWeight::get().writes(1))
@@ -82,8 +82,8 @@ impl<T: frame_system::Config> pallet_bridge_messages::WeightInfo for WeightInfo<
 		// Proof Size summary in bytes:
 		//  Measured:  `538`
 		//  Estimated: `52645`
-		// Minimum execution time: 52_880_000 picoseconds.
-		Weight::from_parts(53_697_000, 0)
+		// Minimum execution time: 50_245_000 picoseconds.
+		Weight::from_parts(51_441_000, 0)
 			.saturating_add(Weight::from_parts(0, 52645))
 			.saturating_add(T::DbWeight::get().reads(5))
 			.saturating_add(T::DbWeight::get().writes(1))
@@ -102,8 +102,8 @@ impl<T: frame_system::Config> pallet_bridge_messages::WeightInfo for WeightInfo<
 		// Proof Size summary in bytes:
 		//  Measured:  `538`
 		//  Estimated: `52645`
-		// Minimum execution time: 47_424_000 picoseconds.
-		Weight::from_parts(48_445_000, 0)
+		// Minimum execution time: 44_572_000 picoseconds.
+		Weight::from_parts(45_629_000, 0)
 			.saturating_add(Weight::from_parts(0, 52645))
 			.saturating_add(T::DbWeight::get().reads(5))
 			.saturating_add(T::DbWeight::get().writes(1))
@@ -120,8 +120,8 @@ impl<T: frame_system::Config> pallet_bridge_messages::WeightInfo for WeightInfo<
 		// Proof Size summary in bytes:
 		//  Measured:  `506`
 		//  Estimated: `52645`
-		// Minimum execution time: 40_619_000 picoseconds.
-		Weight::from_parts(42_262_000, 0)
+		// Minimum execution time: 38_804_000 picoseconds.
+		Weight::from_parts(39_516_000, 0)
 			.saturating_add(Weight::from_parts(0, 52645))
 			.saturating_add(T::DbWeight::get().reads(4))
 			.saturating_add(T::DbWeight::get().writes(1))
@@ -138,8 +138,8 @@ impl<T: frame_system::Config> pallet_bridge_messages::WeightInfo for WeightInfo<
 		// Proof Size summary in bytes:
 		//  Measured:  `506`
 		//  Estimated: `52645`
-		// Minimum execution time: 74_603_000 picoseconds.
-		Weight::from_parts(78_209_000, 0)
+		// Minimum execution time: 68_674_000 picoseconds.
+		Weight::from_parts(72_690_000, 0)
 			.saturating_add(Weight::from_parts(0, 52645))
 			.saturating_add(T::DbWeight::get().reads(4))
 			.saturating_add(T::DbWeight::get().writes(1))
@@ -156,11 +156,11 @@ impl<T: frame_system::Config> pallet_bridge_messages::WeightInfo for WeightInfo<
 	/// Proof: `BridgeRelayers::RelayerRewards` (`max_values`: None, `max_size`: Some(73), added: 2548, mode: `MaxEncodedLen`)
 	fn receive_delivery_proof_for_single_message() -> Weight {
 		// Proof Size summary in bytes:
-		//  Measured:  `377`
-		//  Estimated: `3842`
-		// Minimum execution time: 33_762_000 picoseconds.
-		Weight::from_parts(34_405_000, 0)
-			.saturating_add(Weight::from_parts(0, 3842))
+		//  Measured:  `413`
+		//  Estimated: `3878`
+		// Minimum execution time: 32_833_000 picoseconds.
+		Weight::from_parts(33_442_000, 0)
+			.saturating_add(Weight::from_parts(0, 3878))
 			.saturating_add(T::DbWeight::get().reads(5))
 			.saturating_add(T::DbWeight::get().writes(2))
 	}
@@ -176,11 +176,11 @@ impl<T: frame_system::Config> pallet_bridge_messages::WeightInfo for WeightInfo<
 	/// Proof: `BridgeRelayers::RelayerRewards` (`max_values`: None, `max_size`: Some(73), added: 2548, mode: `MaxEncodedLen`)
 	fn receive_delivery_proof_for_two_messages_by_single_relayer() -> Weight {
 		// Proof Size summary in bytes:
-		//  Measured:  `377`
-		//  Estimated: `3842`
-		// Minimum execution time: 33_805_000 picoseconds.
-		Weight::from_parts(35_051_000, 0)
-			.saturating_add(Weight::from_parts(0, 3842))
+		//  Measured:  `413`
+		//  Estimated: `3878`
+		// Minimum execution time: 32_528_000 picoseconds.
+		Weight::from_parts(33_627_000, 0)
+			.saturating_add(Weight::from_parts(0, 3878))
 			.saturating_add(T::DbWeight::get().reads(5))
 			.saturating_add(T::DbWeight::get().writes(2))
 	}
@@ -196,10 +196,10 @@ impl<T: frame_system::Config> pallet_bridge_messages::WeightInfo for WeightInfo<
 	/// Proof: `BridgeRelayers::RelayerRewards` (`max_values`: None, `max_size`: Some(73), added: 2548, mode: `MaxEncodedLen`)
 	fn receive_delivery_proof_for_two_messages_by_two_relayers() -> Weight {
 		// Proof Size summary in bytes:
-		//  Measured:  `377`
+		//  Measured:  `413`
 		//  Estimated: `6086`
-		// Minimum execution time: 38_612_000 picoseconds.
-		Weight::from_parts(39_412_000, 0)
+		// Minimum execution time: 37_493_000 picoseconds.
+		Weight::from_parts(38_324_000, 0)
 			.saturating_add(Weight::from_parts(0, 6086))
 			.saturating_add(T::DbWeight::get().reads(6))
 			.saturating_add(T::DbWeight::get().writes(3))
@@ -231,11 +231,11 @@ impl<T: frame_system::Config> pallet_bridge_messages::WeightInfo for WeightInfo<
 		// Proof Size summary in bytes:
 		//  Measured:  `669`
 		//  Estimated: `52645`
-		// Minimum execution time: 69_285_000 picoseconds.
-		Weight::from_parts(70_867_498, 0)
+		// Minimum execution time: 64_104_000 picoseconds.
+		Weight::from_parts(66_006_268, 0)
 			.saturating_add(Weight::from_parts(0, 52645))
-			// Standard Error: 111
-			.saturating_add(Weight::from_parts(7_489, 0).saturating_mul(i.into()))
+			// Standard Error: 91
+			.saturating_add(Weight::from_parts(7_932, 0).saturating_mul(i.into()))
 			.saturating_add(T::DbWeight::get().reads(10))
 			.saturating_add(T::DbWeight::get().writes(4))
 	}
diff --git a/cumulus/parachains/runtimes/bridge-hubs/bridge-hub-rococo/src/weights/pallet_bridge_parachains.rs b/cumulus/parachains/runtimes/bridge-hubs/bridge-hub-rococo/src/weights/pallet_bridge_parachains.rs
index 5c7c4a63682..ea68852804e 100644
--- a/cumulus/parachains/runtimes/bridge-hubs/bridge-hub-rococo/src/weights/pallet_bridge_parachains.rs
+++ b/cumulus/parachains/runtimes/bridge-hubs/bridge-hub-rococo/src/weights/pallet_bridge_parachains.rs
@@ -17,9 +17,9 @@
 //! Autogenerated weights for `pallet_bridge_parachains`
 //!
 //! THIS FILE WAS AUTO-GENERATED USING THE SUBSTRATE BENCHMARK CLI VERSION 4.0.0-dev
-//! DATE: 2023-11-14, STEPS: `50`, REPEAT: `20`, LOW RANGE: `[]`, HIGH RANGE: `[]`
+//! DATE: 2023-12-12, STEPS: `50`, REPEAT: `20`, LOW RANGE: `[]`, HIGH RANGE: `[]`
 //! WORST CASE MAP SIZE: `1000000`
-//! HOSTNAME: `runner-yprdrvc7-project-674-concurrent-0`, CPU: `Intel(R) Xeon(R) CPU @ 2.60GHz`
+//! HOSTNAME: `runner-itmxxexx-project-674-concurrent-0`, CPU: `Intel(R) Xeon(R) CPU @ 2.60GHz`
 //! WASM-EXECUTION: `Compiled`, CHAIN: `Some("bridge-hub-rococo-dev")`, DB CACHE: 1024
 
 // Executed Command:
@@ -59,13 +59,15 @@ impl<T: frame_system::Config> pallet_bridge_parachains::WeightInfo for WeightInf
 	/// Storage: `BridgeWestendParachains::ImportedParaHeads` (r:0 w:1)
 	/// Proof: `BridgeWestendParachains::ImportedParaHeads` (`max_values`: Some(64), `max_size`: Some(196), added: 1186, mode: `MaxEncodedLen`)
 	/// The range of component `p` is `[1, 2]`.
-	fn submit_parachain_heads_with_n_parachains(_p: u32, ) -> Weight {
+	fn submit_parachain_heads_with_n_parachains(p: u32, ) -> Weight {
 		// Proof Size summary in bytes:
 		//  Measured:  `434`
 		//  Estimated: `2543`
-		// Minimum execution time: 31_987_000 picoseconds.
-		Weight::from_parts(33_060_534, 0)
+		// Minimum execution time: 31_135_000 picoseconds.
+		Weight::from_parts(32_061_351, 0)
 			.saturating_add(Weight::from_parts(0, 2543))
+			// Standard Error: 80_309
+			.saturating_add(Weight::from_parts(99_724, 0).saturating_mul(p.into()))
 			.saturating_add(T::DbWeight::get().reads(4))
 			.saturating_add(T::DbWeight::get().writes(3))
 	}
@@ -83,8 +85,8 @@ impl<T: frame_system::Config> pallet_bridge_parachains::WeightInfo for WeightInf
 		// Proof Size summary in bytes:
 		//  Measured:  `434`
 		//  Estimated: `2543`
-		// Minimum execution time: 33_360_000 picoseconds.
-		Weight::from_parts(34_182_000, 0)
+		// Minimum execution time: 32_263_000 picoseconds.
+		Weight::from_parts(33_139_000, 0)
 			.saturating_add(Weight::from_parts(0, 2543))
 			.saturating_add(T::DbWeight::get().reads(4))
 			.saturating_add(T::DbWeight::get().writes(3))
@@ -103,8 +105,8 @@ impl<T: frame_system::Config> pallet_bridge_parachains::WeightInfo for WeightInf
 		// Proof Size summary in bytes:
 		//  Measured:  `434`
 		//  Estimated: `2543`
-		// Minimum execution time: 65_246_000 picoseconds.
-		Weight::from_parts(65_985_000, 0)
+		// Minimum execution time: 61_313_000 picoseconds.
+		Weight::from_parts(62_200_000, 0)
 			.saturating_add(Weight::from_parts(0, 2543))
 			.saturating_add(T::DbWeight::get().reads(4))
 			.saturating_add(T::DbWeight::get().writes(3))
diff --git a/cumulus/parachains/runtimes/bridge-hubs/bridge-hub-westend/src/weights/pallet_bridge_parachains.rs b/cumulus/parachains/runtimes/bridge-hubs/bridge-hub-westend/src/weights/pallet_bridge_parachains.rs
index 81cb0a66b7d..9819bd40654 100644
--- a/cumulus/parachains/runtimes/bridge-hubs/bridge-hub-westend/src/weights/pallet_bridge_parachains.rs
+++ b/cumulus/parachains/runtimes/bridge-hubs/bridge-hub-westend/src/weights/pallet_bridge_parachains.rs
@@ -17,10 +17,10 @@
 //! Autogenerated weights for `pallet_bridge_parachains`
 //!
 //! THIS FILE WAS AUTO-GENERATED USING THE SUBSTRATE BENCHMARK CLI VERSION 4.0.0-dev
-//! DATE: 2023-10-26, STEPS: `50`, REPEAT: `20`, LOW RANGE: `[]`, HIGH RANGE: `[]`
+//! DATE: 2023-12-12, STEPS: `50`, REPEAT: `20`, LOW RANGE: `[]`, HIGH RANGE: `[]`
 //! WORST CASE MAP SIZE: `1000000`
-//! HOSTNAME: `runner-vmdtonbz-project-674-concurrent-0`, CPU: `Intel(R) Xeon(R) CPU @ 2.60GHz`
-//! WASM-EXECUTION: `Compiled`, CHAIN: `Some("bridge-hub-rococo-dev")`, DB CACHE: 1024
+//! HOSTNAME: `runner-itmxxexx-project-674-concurrent-0`, CPU: `Intel(R) Xeon(R) CPU @ 2.60GHz`
+//! WASM-EXECUTION: `Compiled`, CHAIN: `Some("bridge-hub-westend-dev")`, DB CACHE: 1024
 
 // Executed Command:
 // target/production/polkadot-parachain
@@ -33,9 +33,9 @@
 // --heap-pages=4096
 // --json-file=/builds/parity/mirrors/polkadot-sdk/.git/.artifacts/bench.json
 // --pallet=pallet_bridge_parachains
-// --chain=bridge-hub-rococo-dev
+// --chain=bridge-hub-westend-dev
 // --header=./cumulus/file_header.txt
-// --output=./cumulus/parachains/runtimes/bridge-hubs/bridge-hub-rococo/src/weights/
+// --output=./cumulus/parachains/runtimes/bridge-hubs/bridge-hub-westend/src/weights/
 
 #![cfg_attr(rustfmt, rustfmt_skip)]
 #![allow(unused_parens)]
@@ -48,65 +48,63 @@ use core::marker::PhantomData;
 /// Weight functions for `pallet_bridge_parachains`.
 pub struct WeightInfo<T>(PhantomData<T>);
 impl<T: frame_system::Config> pallet_bridge_parachains::WeightInfo for WeightInfo<T> {
-	/// Storage: `BridgeRococoParachain::PalletOperatingMode` (r:1 w:0)
-	/// Proof: `BridgeRococoParachain::PalletOperatingMode` (`max_values`: Some(1), `max_size`: Some(1), added: 496, mode: `MaxEncodedLen`)
+	/// Storage: `BridgeRococoParachains::PalletOperatingMode` (r:1 w:0)
+	/// Proof: `BridgeRococoParachains::PalletOperatingMode` (`max_values`: Some(1), `max_size`: Some(1), added: 496, mode: `MaxEncodedLen`)
 	/// Storage: `BridgeRococoGrandpa::ImportedHeaders` (r:1 w:0)
 	/// Proof: `BridgeRococoGrandpa::ImportedHeaders` (`max_values`: Some(1024), `max_size`: Some(68), added: 1553, mode: `MaxEncodedLen`)
-	/// Storage: `BridgeRococoParachain::ParasInfo` (r:1 w:1)
-	/// Proof: `BridgeRococoParachain::ParasInfo` (`max_values`: Some(1), `max_size`: Some(60), added: 555, mode: `MaxEncodedLen`)
-	/// Storage: `BridgeRococoParachain::ImportedParaHashes` (r:1 w:1)
-	/// Proof: `BridgeRococoParachain::ImportedParaHashes` (`max_values`: Some(64), `max_size`: Some(64), added: 1054, mode: `MaxEncodedLen`)
-	/// Storage: `BridgeRococoParachain::ImportedParaHeads` (r:0 w:1)
-	/// Proof: `BridgeRococoParachain::ImportedParaHeads` (`max_values`: Some(64), `max_size`: Some(196), added: 1186, mode: `MaxEncodedLen`)
-	/// The range of component `p` is `[1, 2]`.
-	/// The range of component `p` is `[1, 2]`.
+	/// Storage: `BridgeRococoParachains::ParasInfo` (r:1 w:1)
+	/// Proof: `BridgeRococoParachains::ParasInfo` (`max_values`: Some(1), `max_size`: Some(60), added: 555, mode: `MaxEncodedLen`)
+	/// Storage: `BridgeRococoParachains::ImportedParaHashes` (r:1 w:1)
+	/// Proof: `BridgeRococoParachains::ImportedParaHashes` (`max_values`: Some(64), `max_size`: Some(64), added: 1054, mode: `MaxEncodedLen`)
+	/// Storage: `BridgeRococoParachains::ImportedParaHeads` (r:0 w:1)
+	/// Proof: `BridgeRococoParachains::ImportedParaHeads` (`max_values`: Some(64), `max_size`: Some(196), added: 1186, mode: `MaxEncodedLen`)
 	/// The range of component `p` is `[1, 2]`.
 	fn submit_parachain_heads_with_n_parachains(_p: u32, ) -> Weight {
 		// Proof Size summary in bytes:
-		//  Measured:  `367`
+		//  Measured:  `291`
 		//  Estimated: `2543`
-		// Minimum execution time: 31_241_000 picoseconds.
-		Weight::from_parts(32_488_584, 0)
+		// Minimum execution time: 29_994_000 picoseconds.
+		Weight::from_parts(31_005_636, 0)
 			.saturating_add(Weight::from_parts(0, 2543))
 			.saturating_add(T::DbWeight::get().reads(4))
 			.saturating_add(T::DbWeight::get().writes(3))
 	}
-	/// Storage: `BridgeRococoParachain::PalletOperatingMode` (r:1 w:0)
-	/// Proof: `BridgeRococoParachain::PalletOperatingMode` (`max_values`: Some(1), `max_size`: Some(1), added: 496, mode: `MaxEncodedLen`)
+	/// Storage: `BridgeRococoParachains::PalletOperatingMode` (r:1 w:0)
+	/// Proof: `BridgeRococoParachains::PalletOperatingMode` (`max_values`: Some(1), `max_size`: Some(1), added: 496, mode: `MaxEncodedLen`)
 	/// Storage: `BridgeRococoGrandpa::ImportedHeaders` (r:1 w:0)
 	/// Proof: `BridgeRococoGrandpa::ImportedHeaders` (`max_values`: Some(1024), `max_size`: Some(68), added: 1553, mode: `MaxEncodedLen`)
-	/// Storage: `BridgeRococoParachain::ParasInfo` (r:1 w:1)
-	/// Proof: `BridgeRococoParachain::ParasInfo` (`max_values`: Some(1), `max_size`: Some(60), added: 555, mode: `MaxEncodedLen`)
-	/// Storage: `BridgeRococoParachain::ImportedParaHashes` (r:1 w:1)
-	/// Proof: `BridgeRococoParachain::ImportedParaHashes` (`max_values`: Some(64), `max_size`: Some(64), added: 1054, mode: `MaxEncodedLen`)
-	/// Storage: `BridgeRococoParachain::ImportedParaHeads` (r:0 w:1)
-	/// Proof: `BridgeRococoParachain::ImportedParaHeads` (`max_values`: Some(64), `max_size`: Some(196), added: 1186, mode: `MaxEncodedLen`)
+	/// Storage: `BridgeRococoParachains::ParasInfo` (r:1 w:1)
+	/// Proof: `BridgeRococoParachains::ParasInfo` (`max_values`: Some(1), `max_size`: Some(60), added: 555, mode: `MaxEncodedLen`)
+	/// Storage: `BridgeRococoParachains::ImportedParaHashes` (r:1 w:1)
+	/// Proof: `BridgeRococoParachains::ImportedParaHashes` (`max_values`: Some(64), `max_size`: Some(64), added: 1054, mode: `MaxEncodedLen`)
+	/// Storage: `BridgeRococoParachains::ImportedParaHeads` (r:0 w:1)
+	/// Proof: `BridgeRococoParachains::ImportedParaHeads` (`max_values`: Some(64), `max_size`: Some(196), added: 1186, mode: `MaxEncodedLen`)
 	fn submit_parachain_heads_with_1kb_proof() -> Weight {
 		// Proof Size summary in bytes:
-		//  Measured:  `367`
+		//  Measured:  `291`
 		//  Estimated: `2543`
-		// Minimum execution time: 32_962_000 picoseconds.
-		Weight::from_parts(33_658_000, 0)
+		// Minimum execution time: 31_425_000 picoseconds.
+		Weight::from_parts(32_163_000, 0)
 			.saturating_add(Weight::from_parts(0, 2543))
 			.saturating_add(T::DbWeight::get().reads(4))
 			.saturating_add(T::DbWeight::get().writes(3))
 	}
-	/// Storage: `BridgeRococoParachain::PalletOperatingMode` (r:1 w:0)
-	/// Proof: `BridgeRococoParachain::PalletOperatingMode` (`max_values`: Some(1), `max_size`: Some(1), added: 496, mode: `MaxEncodedLen`)
+	/// Storage: `BridgeRococoParachains::PalletOperatingMode` (r:1 w:0)
+	/// Proof: `BridgeRococoParachains::PalletOperatingMode` (`max_values`: Some(1), `max_size`: Some(1), added: 496, mode: `MaxEncodedLen`)
 	/// Storage: `BridgeRococoGrandpa::ImportedHeaders` (r:1 w:0)
 	/// Proof: `BridgeRococoGrandpa::ImportedHeaders` (`max_values`: Some(1024), `max_size`: Some(68), added: 1553, mode: `MaxEncodedLen`)
-	/// Storage: `BridgeRococoParachain::ParasInfo` (r:1 w:1)
-	/// Proof: `BridgeRococoParachain::ParasInfo` (`max_values`: Some(1), `max_size`: Some(60), added: 555, mode: `MaxEncodedLen`)
-	/// Storage: `BridgeRococoParachain::ImportedParaHashes` (r:1 w:1)
-	/// Proof: `BridgeRococoParachain::ImportedParaHashes` (`max_values`: Some(64), `max_size`: Some(64), added: 1054, mode: `MaxEncodedLen`)
-	/// Storage: `BridgeRococoParachain::ImportedParaHeads` (r:0 w:1)
-	/// Proof: `BridgeRococoParachain::ImportedParaHeads` (`max_values`: Some(64), `max_size`: Some(196), added: 1186, mode: `MaxEncodedLen`)
+	/// Storage: `BridgeRococoParachains::ParasInfo` (r:1 w:1)
+	/// Proof: `BridgeRococoParachains::ParasInfo` (`max_values`: Some(1), `max_size`: Some(60), added: 555, mode: `MaxEncodedLen`)
+	/// Storage: `BridgeRococoParachains::ImportedParaHashes` (r:1 w:1)
+	/// Proof: `BridgeRococoParachains::ImportedParaHashes` (`max_values`: Some(64), `max_size`: Some(64), added: 1054, mode: `MaxEncodedLen`)
+	/// Storage: `BridgeRococoParachains::ImportedParaHeads` (r:0 w:1)
+	/// Proof: `BridgeRococoParachains::ImportedParaHeads` (`max_values`: Some(64), `max_size`: Some(196), added: 1186, mode: `MaxEncodedLen`)
 	fn submit_parachain_heads_with_16kb_proof() -> Weight {
 		// Proof Size summary in bytes:
-		//  Measured:  `367`
+		//  Measured:  `291`
 		//  Estimated: `2543`
-		// Minimum execution time: 62_685_000 picoseconds.
-		Weight::from_parts(64_589_000, 0)
+		// Minimum execution time: 60_062_000 picoseconds.
+		Weight::from_parts(61_201_000, 0)
 			.saturating_add(Weight::from_parts(0, 2543))
 			.saturating_add(T::DbWeight::get().reads(4))
 			.saturating_add(T::DbWeight::get().writes(3))
diff --git a/cumulus/parachains/runtimes/bridge-hubs/bridge-hub-westend/src/weights/xcm/pallet_xcm_benchmarks_generic.rs b/cumulus/parachains/runtimes/bridge-hubs/bridge-hub-westend/src/weights/xcm/pallet_xcm_benchmarks_generic.rs
index 8f283403400..9281a880c7e 100644
--- a/cumulus/parachains/runtimes/bridge-hubs/bridge-hub-westend/src/weights/xcm/pallet_xcm_benchmarks_generic.rs
+++ b/cumulus/parachains/runtimes/bridge-hubs/bridge-hub-westend/src/weights/xcm/pallet_xcm_benchmarks_generic.rs
@@ -17,9 +17,9 @@
 //! Autogenerated weights for `pallet_xcm_benchmarks::generic`
 //!
 //! THIS FILE WAS AUTO-GENERATED USING THE SUBSTRATE BENCHMARK CLI VERSION 4.0.0-dev
-//! DATE: 2023-11-29, STEPS: `50`, REPEAT: `20`, LOW RANGE: `[]`, HIGH RANGE: `[]`
+//! DATE: 2023-12-12, STEPS: `50`, REPEAT: `20`, LOW RANGE: `[]`, HIGH RANGE: `[]`
 //! WORST CASE MAP SIZE: `1000000`
-//! HOSTNAME: `runner-r43aesjn-project-674-concurrent-0`, CPU: `Intel(R) Xeon(R) CPU @ 2.60GHz`
+//! HOSTNAME: `runner-itmxxexx-project-674-concurrent-0`, CPU: `Intel(R) Xeon(R) CPU @ 2.60GHz`
 //! WASM-EXECUTION: Compiled, CHAIN: Some("bridge-hub-westend-dev"), DB CACHE: 1024
 
 // Executed Command:
@@ -66,10 +66,10 @@ impl<T: frame_system::Config> WeightInfo<T> {
 	// Proof: `ParachainSystem::PendingUpwardMessages` (`max_values`: Some(1), `max_size`: None, mode: `Measured`)
 	pub fn report_holding() -> Weight {
 		// Proof Size summary in bytes:
-		//  Measured:  `171`
+		//  Measured:  `208`
 		//  Estimated: `6196`
-		// Minimum execution time: 61_383_000 picoseconds.
-		Weight::from_parts(62_382_000, 6196)
+		// Minimum execution time: 61_577_000 picoseconds.
+		Weight::from_parts(63_216_000, 6196)
 			.saturating_add(T::DbWeight::get().reads(9))
 			.saturating_add(T::DbWeight::get().writes(4))
 	}
@@ -77,8 +77,8 @@ impl<T: frame_system::Config> WeightInfo<T> {
 		// Proof Size summary in bytes:
 		//  Measured:  `0`
 		//  Estimated: `0`
-		// Minimum execution time: 2_057_000 picoseconds.
-		Weight::from_parts(2_153_000, 0)
+		// Minimum execution time: 2_019_000 picoseconds.
+		Weight::from_parts(2_146_000, 0)
 	}
 	// Storage: `PolkadotXcm::Queries` (r:1 w:0)
 	// Proof: `PolkadotXcm::Queries` (`max_values`: None, `max_size`: None, mode: `Measured`)
@@ -86,58 +86,58 @@ impl<T: frame_system::Config> WeightInfo<T> {
 		// Proof Size summary in bytes:
 		//  Measured:  `32`
 		//  Estimated: `3497`
-		// Minimum execution time: 7_949_000 picoseconds.
-		Weight::from_parts(8_250_000, 3497)
+		// Minimum execution time: 7_473_000 picoseconds.
+		Weight::from_parts(7_784_000, 3497)
 			.saturating_add(T::DbWeight::get().reads(1))
 	}
 	pub fn transact() -> Weight {
 		// Proof Size summary in bytes:
 		//  Measured:  `0`
 		//  Estimated: `0`
-		// Minimum execution time: 8_608_000 picoseconds.
-		Weight::from_parts(9_086_000, 0)
+		// Minimum execution time: 8_385_000 picoseconds.
+		Weight::from_parts(8_768_000, 0)
 	}
 	pub fn refund_surplus() -> Weight {
 		// Proof Size summary in bytes:
 		//  Measured:  `0`
 		//  Estimated: `0`
-		// Minimum execution time: 2_240_000 picoseconds.
-		Weight::from_parts(2_348_000, 0)
+		// Minimum execution time: 2_181_000 picoseconds.
+		Weight::from_parts(2_304_000, 0)
 	}
 	pub fn set_error_handler() -> Weight {
 		// Proof Size summary in bytes:
 		//  Measured:  `0`
 		//  Estimated: `0`
-		// Minimum execution time: 1_969_000 picoseconds.
-		Weight::from_parts(2_017_000, 0)
+		// Minimum execution time: 1_858_000 picoseconds.
+		Weight::from_parts(1_919_000, 0)
 	}
 	pub fn set_appendix() -> Weight {
 		// Proof Size summary in bytes:
 		//  Measured:  `0`
 		//  Estimated: `0`
-		// Minimum execution time: 1_907_000 picoseconds.
-		Weight::from_parts(2_001_000, 0)
+		// Minimum execution time: 1_855_000 picoseconds.
+		Weight::from_parts(1_979_000, 0)
 	}
 	pub fn clear_error() -> Weight {
 		// Proof Size summary in bytes:
 		//  Measured:  `0`
 		//  Estimated: `0`
-		// Minimum execution time: 1_880_000 picoseconds.
-		Weight::from_parts(1_975_000, 0)
+		// Minimum execution time: 1_823_000 picoseconds.
+		Weight::from_parts(1_890_000, 0)
 	}
 	pub fn descend_origin() -> Weight {
 		// Proof Size summary in bytes:
 		//  Measured:  `0`
 		//  Estimated: `0`
-		// Minimum execution time: 2_549_000 picoseconds.
-		Weight::from_parts(2_624_000, 0)
+		// Minimum execution time: 2_407_000 picoseconds.
+		Weight::from_parts(2_507_000, 0)
 	}
 	pub fn clear_origin() -> Weight {
 		// Proof Size summary in bytes:
 		//  Measured:  `0`
 		//  Estimated: `0`
-		// Minimum execution time: 1_895_000 picoseconds.
-		Weight::from_parts(1_963_000, 0)
+		// Minimum execution time: 1_838_000 picoseconds.
+		Weight::from_parts(1_894_000, 0)
 	}
 	// Storage: `ParachainInfo::ParachainId` (r:1 w:0)
 	// Proof: `ParachainInfo::ParachainId` (`max_values`: Some(1), `max_size`: Some(4), added: 499, mode: `MaxEncodedLen`)
@@ -157,10 +157,10 @@ impl<T: frame_system::Config> WeightInfo<T> {
 	// Proof: `ParachainSystem::PendingUpwardMessages` (`max_values`: Some(1), `max_size`: None, mode: `Measured`)
 	pub fn report_error() -> Weight {
 		// Proof Size summary in bytes:
-		//  Measured:  `171`
+		//  Measured:  `208`
 		//  Estimated: `6196`
-		// Minimum execution time: 54_447_000 picoseconds.
-		Weight::from_parts(55_629_000, 6196)
+		// Minimum execution time: 54_847_000 picoseconds.
+		Weight::from_parts(55_742_000, 6196)
 			.saturating_add(T::DbWeight::get().reads(9))
 			.saturating_add(T::DbWeight::get().writes(4))
 	}
@@ -170,8 +170,8 @@ impl<T: frame_system::Config> WeightInfo<T> {
 		// Proof Size summary in bytes:
 		//  Measured:  `90`
 		//  Estimated: `3555`
-		// Minimum execution time: 11_597_000 picoseconds.
-		Weight::from_parts(11_809_000, 3555)
+		// Minimum execution time: 10_614_000 picoseconds.
+		Weight::from_parts(11_344_000, 3555)
 			.saturating_add(T::DbWeight::get().reads(1))
 			.saturating_add(T::DbWeight::get().writes(1))
 	}
@@ -179,8 +179,8 @@ impl<T: frame_system::Config> WeightInfo<T> {
 		// Proof Size summary in bytes:
 		//  Measured:  `0`
 		//  Estimated: `0`
-		// Minimum execution time: 1_895_000 picoseconds.
-		Weight::from_parts(1_977_000, 0)
+		// Minimum execution time: 1_826_000 picoseconds.
+		Weight::from_parts(1_899_000, 0)
 	}
 	// Storage: `PolkadotXcm::VersionNotifyTargets` (r:1 w:1)
 	// Proof: `PolkadotXcm::VersionNotifyTargets` (`max_values`: None, `max_size`: None, mode: `Measured`)
@@ -200,8 +200,8 @@ impl<T: frame_system::Config> WeightInfo<T> {
 		// Proof Size summary in bytes:
 		//  Measured:  `38`
 		//  Estimated: `3503`
-		// Minimum execution time: 23_314_000 picoseconds.
-		Weight::from_parts(23_905_000, 3503)
+		// Minimum execution time: 22_312_000 picoseconds.
+		Weight::from_parts(22_607_000, 3503)
 			.saturating_add(T::DbWeight::get().reads(7))
 			.saturating_add(T::DbWeight::get().writes(3))
 	}
@@ -211,44 +211,44 @@ impl<T: frame_system::Config> WeightInfo<T> {
 		// Proof Size summary in bytes:
 		//  Measured:  `0`
 		//  Estimated: `0`
-		// Minimum execution time: 3_948_000 picoseconds.
-		Weight::from_parts(4_084_000, 0)
+		// Minimum execution time: 3_728_000 picoseconds.
+		Weight::from_parts(3_914_000, 0)
 			.saturating_add(T::DbWeight::get().writes(1))
 	}
 	pub fn burn_asset() -> Weight {
 		// Proof Size summary in bytes:
 		//  Measured:  `0`
 		//  Estimated: `0`
-		// Minimum execution time: 3_196_000 picoseconds.
-		Weight::from_parts(3_285_000, 0)
+		// Minimum execution time: 3_054_000 picoseconds.
+		Weight::from_parts(3_140_000, 0)
 	}
 	pub fn expect_asset() -> Weight {
 		// Proof Size summary in bytes:
 		//  Measured:  `0`
 		//  Estimated: `0`
-		// Minimum execution time: 2_040_000 picoseconds.
-		Weight::from_parts(2_162_000, 0)
+		// Minimum execution time: 1_996_000 picoseconds.
+		Weight::from_parts(2_148_000, 0)
 	}
 	pub fn expect_origin() -> Weight {
 		// Proof Size summary in bytes:
 		//  Measured:  `0`
 		//  Estimated: `0`
-		// Minimum execution time: 1_980_000 picoseconds.
-		Weight::from_parts(2_082_000, 0)
+		// Minimum execution time: 2_008_000 picoseconds.
+		Weight::from_parts(2_077_000, 0)
 	}
 	pub fn expect_error() -> Weight {
 		// Proof Size summary in bytes:
 		//  Measured:  `0`
 		//  Estimated: `0`
-		// Minimum execution time: 1_890_000 picoseconds.
-		Weight::from_parts(1_971_000, 0)
+		// Minimum execution time: 1_837_000 picoseconds.
+		Weight::from_parts(1_913_000, 0)
 	}
 	pub fn expect_transact_status() -> Weight {
 		// Proof Size summary in bytes:
 		//  Measured:  `0`
 		//  Estimated: `0`
-		// Minimum execution time: 2_131_000 picoseconds.
-		Weight::from_parts(2_187_000, 0)
+		// Minimum execution time: 2_052_000 picoseconds.
+		Weight::from_parts(2_120_000, 0)
 	}
 	// Storage: `ParachainInfo::ParachainId` (r:1 w:0)
 	// Proof: `ParachainInfo::ParachainId` (`max_values`: Some(1), `max_size`: Some(4), added: 499, mode: `MaxEncodedLen`)
@@ -268,10 +268,10 @@ impl<T: frame_system::Config> WeightInfo<T> {
 	// Proof: `ParachainSystem::PendingUpwardMessages` (`max_values`: Some(1), `max_size`: None, mode: `Measured`)
 	pub fn query_pallet() -> Weight {
 		// Proof Size summary in bytes:
-		//  Measured:  `171`
+		//  Measured:  `208`
 		//  Estimated: `6196`
-		// Minimum execution time: 59_548_000 picoseconds.
-		Weight::from_parts(60_842_000, 6196)
+		// Minimum execution time: 58_725_000 picoseconds.
+		Weight::from_parts(60_271_000, 6196)
 			.saturating_add(T::DbWeight::get().reads(9))
 			.saturating_add(T::DbWeight::get().writes(4))
 	}
@@ -279,8 +279,8 @@ impl<T: frame_system::Config> WeightInfo<T> {
 		// Proof Size summary in bytes:
 		//  Measured:  `0`
 		//  Estimated: `0`
-		// Minimum execution time: 4_665_000 picoseconds.
-		Weight::from_parts(4_844_000, 0)
+		// Minimum execution time: 4_570_000 picoseconds.
+		Weight::from_parts(4_707_000, 0)
 	}
 	// Storage: `ParachainInfo::ParachainId` (r:1 w:0)
 	// Proof: `ParachainInfo::ParachainId` (`max_values`: Some(1), `max_size`: Some(4), added: 499, mode: `MaxEncodedLen`)
@@ -300,10 +300,10 @@ impl<T: frame_system::Config> WeightInfo<T> {
 	// Proof: `ParachainSystem::PendingUpwardMessages` (`max_values`: Some(1), `max_size`: None, mode: `Measured`)
 	pub fn report_transact_status() -> Weight {
 		// Proof Size summary in bytes:
-		//  Measured:  `171`
+		//  Measured:  `208`
 		//  Estimated: `6196`
-		// Minimum execution time: 55_044_000 picoseconds.
-		Weight::from_parts(56_103_000, 6196)
+		// Minimum execution time: 54_903_000 picoseconds.
+		Weight::from_parts(55_711_000, 6196)
 			.saturating_add(T::DbWeight::get().reads(9))
 			.saturating_add(T::DbWeight::get().writes(4))
 	}
@@ -311,29 +311,27 @@ impl<T: frame_system::Config> WeightInfo<T> {
 		// Proof Size summary in bytes:
 		//  Measured:  `0`
 		//  Estimated: `0`
-		// Minimum execution time: 1_904_000 picoseconds.
-		Weight::from_parts(1_984_000, 0)
+		// Minimum execution time: 1_872_000 picoseconds.
+		Weight::from_parts(1_938_000, 0)
 	}
 	pub fn set_topic() -> Weight {
 		// Proof Size summary in bytes:
 		//  Measured:  `0`
 		//  Estimated: `0`
-		// Minimum execution time: 1_889_000 picoseconds.
-		Weight::from_parts(1_950_000, 0)
+		// Minimum execution time: 1_836_000 picoseconds.
+		Weight::from_parts(1_903_000, 0)
 	}
 	pub fn clear_topic() -> Weight {
 		// Proof Size summary in bytes:
 		//  Measured:  `0`
 		//  Estimated: `0`
-		// Minimum execution time: 1_878_000 picoseconds.
-		Weight::from_parts(1_963_000, 0)
+		// Minimum execution time: 1_847_000 picoseconds.
+		Weight::from_parts(1_900_000, 0)
 	}
 	// Storage: `ParachainInfo::ParachainId` (r:1 w:0)
 	// Proof: `ParachainInfo::ParachainId` (`max_values`: Some(1), `max_size`: Some(4), added: 499, mode: `MaxEncodedLen`)
 	// Storage: `PolkadotXcm::SupportedVersion` (r:2 w:0)
 	// Proof: `PolkadotXcm::SupportedVersion` (`max_values`: None, `max_size`: None, mode: `Measured`)
-	// Storage: `PolkadotXcm::VersionDiscoveryQueue` (r:1 w:1)
-	// Proof: `PolkadotXcm::VersionDiscoveryQueue` (`max_values`: Some(1), `max_size`: None, mode: `Measured`)
 	// Storage: `BridgeRococoMessages::PalletOperatingMode` (r:1 w:0)
 	// Proof: `BridgeRococoMessages::PalletOperatingMode` (`max_values`: Some(1), `max_size`: Some(2), added: 497, mode: `MaxEncodedLen`)
 	// Storage: `BridgeRococoMessages::OutboundLanes` (r:1 w:1)
@@ -345,27 +343,27 @@ impl<T: frame_system::Config> WeightInfo<T> {
 	/// The range of component `x` is `[1, 1000]`.
 	pub fn export_message(x: u32, ) -> Weight {
 		// Proof Size summary in bytes:
-		//  Measured:  `188`
-		//  Estimated: `6128`
-		// Minimum execution time: 36_960_000 picoseconds.
-		Weight::from_parts(38_104_333, 6128)
-			// Standard Error: 510
-			.saturating_add(Weight::from_parts(316_499, 0).saturating_mul(x.into()))
-			.saturating_add(T::DbWeight::get().reads(7))
-			.saturating_add(T::DbWeight::get().writes(3))
+		//  Measured:  `225`
+		//  Estimated: `6165`
+		// Minimum execution time: 41_750_000 picoseconds.
+		Weight::from_parts(43_496_915, 6165)
+			// Standard Error: 623
+			.saturating_add(Weight::from_parts(457_907, 0).saturating_mul(x.into()))
+			.saturating_add(T::DbWeight::get().reads(6))
+			.saturating_add(T::DbWeight::get().writes(2))
 	}
 	pub fn set_fees_mode() -> Weight {
 		// Proof Size summary in bytes:
 		//  Measured:  `0`
 		//  Estimated: `0`
-		// Minimum execution time: 1_833_000 picoseconds.
-		Weight::from_parts(1_950_000, 0)
+		// Minimum execution time: 1_826_000 picoseconds.
+		Weight::from_parts(1_911_000, 0)
 	}
 	pub fn unpaid_execution() -> Weight {
 		// Proof Size summary in bytes:
 		//  Measured:  `0`
 		//  Estimated: `0`
-		// Minimum execution time: 1_980_000 picoseconds.
-		Weight::from_parts(2_065_000, 0)
+		// Minimum execution time: 1_967_000 picoseconds.
+		Weight::from_parts(2_096_000, 0)
 	}
 }
-- 
GitLab